@@ -1,4 +1,4 @@
-/*  $Id: ident.c,v 1.6 1999/12/14 04:16:24 kondou Exp $
+/*  $Id: ident.c,v 1.6.2.2 2001/05/24 02:34:26 kondou Exp $
 **
 **  ident authenticator.
 */
@@ -10,10 +10,15 @@
 #include <netdb.h>
 #include <syslog.h>
 #include <sys/socket.h>
+#include <sys/signal.h>
 
 #include "libinn.h"
 #include "macros.h"
 
+void out() {
+    exit(1);
+}
+
 int main(int argc, char *argv[])
 {
     struct servent *s;
@@ -27,7 +32,9 @@ int main(int argc, char *argv[])
     char *endstr;
     int gotcliaddr, gotcliport, gotlocaddr, gotlocport;
 
-    bzero(&sin, sizeof(sin));
+    signal(SIGALRM,out);
+    alarm(15);
+    memset(&sin, '\0', sizeof(sin));
     sin.sin_family = AF_INET;
 
 #define IDENT_PORT 113
@@ -63,9 +70,9 @@ int main(int argc, char *argv[])
 #define PORTNAME "ClientPort: "
 #define LOCIP "LocalIP: "
 #define LOCPORT "LocalPort: "
-    bzero(&cli, sizeof(cli));
+    memset(&cli, '\0', sizeof(cli));
     cli.sin_family = AF_INET;
-    bzero(&loc, sizeof(loc));
+    memset(&loc, '\0', sizeof(loc));
     loc.sin_family = AF_INET;
 
     gotcliaddr = gotcliport = gotlocaddr = gotlocport = 0;
