@@ -1,4 +1,4 @@
-/*  $Id: radius.c,v 1.13.2.6 2001/07/19 21:13:02 rra Exp $
+/*  $Id: radius.c,v 1.13.2.7 2002/08/26 23:59:03 rra Exp $
 **
 **  Authenticate a user against a remote radius server.
 */
@@ -163,7 +163,7 @@ int rad_auth(rad_config_t *config, char *uname, char *pass)
     struct sockaddr_in sinl, sinr;
     int sock;
     struct hostent *hent;
-    int done;
+    int done = 0;
     int ret;
     int reqlen;
     int passlen;
