@@ -1,4 +1,4 @@
-/*  $Revision: 1.24.2.2 $
+/*  $Revision: 1.24.2.3 $
 **
 **  Parse input to add to news overview database.
 */
@@ -106,7 +106,9 @@ int main(int ac, char *av[])
     if (ReadInnConf() < 0) exit(1);
     (void)umask(NEWSUMASK);
     if (innconf->enableoverview && !innconf->useoverchan)
-	syslog(L_ERROR, "overchan runs while innd creates overview data(you can ignore this message if you run makehistory '-F')");
+	syslog(L_ERROR, "overchan is running while innd is creating"
+               " overview data (you can ignore this message if you are"
+               " running makehistory -F)");
 
     ac -= 1;
     av += 1;
