@@ -1,8 +1,8 @@
-/*  $Id: encode.c 6119 2003-01-13 07:59:39Z rra $
-**
+/*  $Revision: 1.3 $
 **  Produce a seven-bit printable encoding of stdin on stdout.
 **  From @(#)encode.c 1.3 5/15/85, distributed with B2.11 News.
 **
+**
 **  The encoding uses characters from 0x20 (' ') through 0x7A ('z').
 **  (That fits nicely into the UUCP 'f' protocol by Piet Beertema.) First,
 **  expand three eight-bit charcters into four six-bit ones.  Collect
@@ -15,8 +15,9 @@
 **  And if you thought that was unclear, then we won't even get into the
 **  terminating conditions!
 */
-
-#include "config.h"
+#include <stdio.h>
+#include <sys/types.h>
+#include "configdata.h"
 #include "clibrary.h"
 
 
@@ -34,10 +35,12 @@ static int	Count;
 
 
 static void
-dumpcode(char *p, int n)
+dumpcode(p, n)
+    register char	*p;
+    register int	n;
 {
-    int	last;
-    int	c;
+    register int	last;
+    register int	c;
 
     if (n == 13) {
 	n--;
@@ -55,27 +58,29 @@ dumpcode(char *p, int n)
 	    c |= (1 << 12);
 	last <<= 1;
 
-	putchar((c / 91) + ' ');
-	putchar((c % 91) + ' ');
+	(void)putchar((c / 91) + ' ');
+	(void)putchar((c % 91) + ' ');
     }
 }
 
 static void
-flushout(void)
+flushout()
 {
-    putchar(ENDMARK1);
-    putchar(ENDMARK2);
-    putchar(Count + ' ');
+    (void)putchar(ENDMARK1);
+    (void)putchar(ENDMARK2);
+    (void)putchar(Count + ' ');
     dumpcode(Buffer, Count);
 }
 
 
 static void
-encode(char *dest, int n)
+encode(dest, n)
+    register char	*dest;
+    int			n;
 {
-    char	*p;
-    int	i;
-    int	j;
+    register char	*p;
+    register int	i;
+    register int	j;
     char		b4[4];
 
     b4[0] = (dest[0] >> 2) & 0x3F;
@@ -98,8 +103,8 @@ encode(char *dest, int n)
 int
 main(void)
 {
-    char	*p;
-    int	c;
+    register char	*p;
+    register int	c;
     char		b3[3];
 
     for (p = b3; (c = getchar()) != EOF; ) {
