@@ -1,6 +1,15 @@
 #ifndef __DBZ_H__
 #define __DBZ_H__
 
+/* Need the definition of HASH. */
+#ifndef __LIBINN_H__
+# include "libinn.h"
+#endif
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /* This is the number of bytes of the md5 to actually store in
  * the .pag file.  This number directly effects the collision
  * rate and memory usage.  You can probably set this number as
@@ -15,8 +24,6 @@
 #define DBZ_INTERNAL_HASH_SIZE   4
 #else
 #define DBZ_INTERNAL_HASH_SIZE   6
-#define HISTOFFSET	0
-#define OVEROFFSET	1
 #endif
 
 typedef enum {DBZSTORE_OK, DBZSTORE_EXISTS, DBZSTORE_ERROR} DBZSTORE_RESULT;
@@ -28,11 +35,7 @@ typedef struct {
        called.  */
     BOOL             writethrough;
     /* Whether to do hash lookups from disk, memory or a mmap'ed file */
-#ifdef	DO_TAGGED_HASH
     dbz_incore_val   pag_incore;
-#else
-    dbz_incore_val   idx_incore;
-#endif
     dbz_incore_val   exists_incore;
     /* Whether dbzstore should update the database async or sync.  This
        is only applicable if you're not mmaping the database */
@@ -53,15 +56,6 @@ typedef struct {
 typedef struct {
     char		hash[DBZ_INTERNAL_HASH_SIZE];
 } PACKED erec;
-typedef struct {
-    OFFSET_T		offset;
-} PACKED idxrec;
-typedef struct {
-    OFFSET_T		offset[2];
-    unsigned char	overindex;
-    unsigned char	reserved;
-    unsigned short	overlen;
-} PACKED idxrecext;
 #if !defined(lint) && (defined(__SUNPRO_C) || defined(_nec_ews))
 #pragma pack()
 #endif /* nor lint, nor__SUNPRO_C, nor _nec_ews */
@@ -74,17 +68,16 @@ extern BOOL dbzclose(void);
 extern BOOL dbzfresh(const char *name, const OFFSET_T size, const int fillpercent);
 extern BOOL dbzagain(const char *name, const char *oldname);
 extern BOOL dbzexists(const HASH key);
-#ifdef	DO_TAGGED_HASH
-extern OFFSET_T dbzfetch(const HASH key);
+extern BOOL dbzfetch(const HASH key, OFFSET_T *value);
 extern DBZSTORE_RESULT dbzstore(const HASH key, const OFFSET_T data);
-#else
-extern BOOL dbzfetch(const HASH key, void *ivalue);
-extern DBZSTORE_RESULT dbzstore(const HASH key, void *ivalue);
-#endif
 extern BOOL dbzsync(void);
 extern long dbzsize(const OFFSET_T contents);
 extern BOOL dbzdebug(const int value);
 extern void dbzsetoptions(const dbzoptions options);
 extern void dbzgetoptions(dbzoptions *options);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* __DBZ_H__ */
