@@ -1,4 +1,4 @@
-/*  $Id: libinn.h,v 1.74.2.4 2002/03/25 19:48:43 rra Exp $
+/*  $Id: libinn.h,v 1.74.2.6 2002/11/25 00:27:22 kondou Exp $
 **
 **  Here be declarations of functions in the InterNetNews library.
 */
@@ -15,6 +15,12 @@
 #include <sys/stat.h>
 #include <sys/uio.h>
 
+/* Linux defines some of these.  Later versions of INN will use different
+   symbols, but this is the simple fix. */
+#undef LOCK_READ
+#undef LOCK_WRITE
+#undef LOCK_UNLOCK
+
 /* Tell C++ not to mangle prototypes. */
 #ifdef __cplusplus
 extern "C" {
@@ -59,6 +65,7 @@ extern void	        HeaderCleanFrom(char *from);
 extern struct _DDHANDLE	*DDstart(FILE *FromServer, FILE *ToServer);
 extern void		DDcheck(struct _DDHANDLE *h, char *group);
 extern char		*DDend(struct _DDHANDLE *h);
+extern char		*FindEndOfHeader(const char *Body, const char *EndOfData);
 
 /* NNTP functions. */
 extern int	NNTPlocalopen(FILE **FromServerp, FILE **ToServerp, char *errbuff);
