@@ -1,4 +1,4 @@
-/*  $Id: cc.c,v 1.70 1999/11/21 00:15:24 rra Exp $
+/*  $Id: cc.c,v 1.70.2.3 2002/10/05 21:52:05 rra Exp $
 **
 **  Routines for the control channel.  Create a Unix-domain datagram socket
 **  that processes on the local server send messages to.  The control
@@ -630,40 +630,6 @@ CCfilter(av)
 #endif /* defined(DO_TCL) */
 
 
-#if defined(DO_PERL)
-
-#include <EXTERN.h>
-#include <perl.h>
-
-extern CV *perl_filter_cv ;
-
-STATIC STRING
-CCperl(av)
-    char	*av[];
-{
-    extern int	PerlFilterActive;
-
-    switch (av[0][0]) {
-    default:
-	return "1 Bad flag";
-    case 'y':
-	if (PerlFilterActive)
-	    return "1 Perl filter already enabled";
-        else if (perl_filter_cv == NULL)
-            return "1 Perl filter not defined" ;
-	PerlFilter(TRUE);
-	break;
-    case 'n':
-	if (!PerlFilterActive)
-	    return "1 Perl filter already disabled";
-	PerlFilter(FALSE);
-	break;
-    }
-    return NULL;
-}
-#endif /* defined(DO_PERL) */
-
-
 #if defined(DO_PYTHON)
 STATIC STRING
 CCpython(av)
@@ -2098,3 +2064,41 @@ STATIC STRING CClowmark(char *av[])
     ICDwrite();
     return ret;
 }
+
+
+
+/* This is last because Perl 5.8.0 does some really odd things with
+   redefinitions of standard functions. */
+
+#if defined(DO_PERL)
+
+#include <EXTERN.h>
+#include <perl.h>
+
+extern CV *perl_filter_cv ;
+
+STATIC STRING
+CCperl(av)
+    char	*av[];
+{
+    extern int	PerlFilterActive;
+
+    switch (av[0][0]) {
+    default:
+	return "1 Bad flag";
+    case 'y':
+	if (PerlFilterActive)
+	    return "1 Perl filter already enabled";
+        else if (perl_filter_cv == NULL)
+            return "1 Perl filter not defined" ;
+	PerlFilter(TRUE);
+	break;
+    case 'n':
+	if (!PerlFilterActive)
+	    return "1 Perl filter already disabled";
+	PerlFilter(FALSE);
+	break;
+    }
+    return NULL;
+}
+#endif /* defined(DO_PERL) */
