@@ -1,4 +1,4 @@
-/*  $Id: perl.c,v 1.15 1999/11/19 09:00:04 rra Exp $
+/*  $Id: perl.c,v 1.15.2.1 2000/10/01 22:54:37 kondou Exp $
 **
 **  Perl filtering support for innd.
 **
@@ -279,7 +279,7 @@ XS(XS_INN_addhist)
 
     /* If any of the times are missing, they should default to now. */
     if (i < 4) {
-        sprintf(tbuff, "%ld", time((long *) 0));
+        sprintf(tbuff, "%ld", (long) time((time_t *) 0));
         for (; i < 4; i++)
             parambuf[i] = tbuff;
     }
