@@ -1,5 +1,5 @@
 /*
-**  $Id: python.c,v 1.5.2.1 2000/12/10 12:55:58 kondou Exp $
+**  $Id: python.c,v 1.5.2.2 2001/10/04 01:35:40 kondou Exp $
 **
 **  python.c: Embed Python in the style of innd's TCL and Perl stuff.
 ** 
@@ -526,7 +526,7 @@ PY_hashstring(self, args)
 	p = wpos;
 	q = workstring;
 	for (i=0 ; i<worksize ; i++) {
-	    if isspace(*p) {
+	    if (isspace(*p)) {
 		if (!wasspace)
 		    *q++ = ' ';
 		wasspace = 1;
