@@ -1,30 +1,65 @@
-/*  $Id: endpoint.c 9895 2015-06-14 10:08:21Z iulius $
-**
-**  The implementation of the innfeed EndPoint object class.
-**
-**  Written by James Brister <brister@vix.com>
-**
-**  The EndPoint class is what gives the illusion (sort of, kind of) of
-**  threading.  Basically it controls a select loop and a set of EndPoint
-**  objects.  Each EndPoint has a file descriptor it is interested in.  The
-**  users of the EndPoint tell the EndPoints to notify them when a read or
-**  write has been completed (or simple if the file descriptor is read or
-**  write ready).
-*/
+/* -*- c -*-
+ *
+ * Author:      James Brister <brister@vix.com> -- berkeley-unix --
+ * Start Date:  Wed Nov 29 23:08:24 1995
+ * Project:     INN (innfeed)
+ * File:        endpoint.c
+ * RCSId:       $Id: endpoint.c,v 1.16 1999/11/21 00:11:42 rra Exp $
+ *
+ * Copyright:   Copyright (c) 1996 by Internet Software Consortium
+ *
+ *              Permission to use, copy, modify, and distribute this
+ *              software for any purpose with or without fee is hereby
+ *              granted, provided that the above copyright notice and this
+ *              permission notice appear in all copies.
+ *
+ *              THE SOFTWARE IS PROVIDED "AS IS" AND INTERNET SOFTWARE
+ *              CONSORTIUM DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
+ *              SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+ *              MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL INTERNET
+ *              SOFTWARE CONSORTIUM BE LIABLE FOR ANY SPECIAL, DIRECT,
+ *              INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+ *              WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ *              WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
+ *              TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE
+ *              USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * Description: The implementation of the EndPoint object class.
+ *
+ *              The EndPoint class is what gives the illusion 9sort
+ *              of, kind of) of threading. Basically it controls a
+ *              select loop and a set of EndPoint objects. Each
+ *              EndPoint has a file descriptor it is interested
+ *              in. The users of the EndPoint tell the EndPoints to
+ *              notify them when a read or write has been completed
+ *              (or simple if the file descriptor is read or write
+ *              ready).
+ *
+ */
+
+#if ! defined (lint)
+static char rcsid [] = "$Id: endpoint.c,v 1.16 1999/11/21 00:11:42 rra Exp $" ;
+static void use_rcsid (const char *rId) {   /* Never called */
+  use_rcsid (rcsid) ; use_rcsid (rId) ;
+} 
+#endif
 
 #include "innfeed.h"
 #include "config.h"
 #include "clibrary.h"
-#include "portable/socket.h"
 
 #include <assert.h>
 #include <errno.h>
-#include <fcntl.h>
 #include <signal.h>
+#include <sys/socket.h>
 #include <sys/stat.h>
 #include <sys/uio.h>
 #include <syslog.h>
 
+#ifdef HAVE_FCNTL_H
+# include <fcntl.h>
+#endif
+
 #ifdef HAVE_LIMITS_H
 # include <limits.h>
 #endif
@@ -33,24 +68,35 @@
 # include <sys/select.h>
 #endif
 
-#ifdef HAVE_SYS_TIME_H
+#ifdef TIME_WITH_SYS_TIME
 # include <sys/time.h>
+# include <time.h>
+#else
+# ifdef HAVE_SYS_TIME_H
+#  include <sys/time.h>
+# else
+#  include <time.h>
+# endif
 #endif
-#include <time.h>
 
-#include "inn/innconf.h"
-#include "inn/messages.h"
-#include "inn/libinn.h"
+#include "libinn.h"
 
 #include "buffer.h"
 #include "configfile.h"
 #include "endpoint.h"
 #include "host.h"
+#include "msgs.h"
 
-static const char *const timer_name[] = {
-  "idle", "blstats", "stsfile", "newart", "readart", "prepart", "read",
-  "write", "cb"
+
+#if defined (__bsdi__) && (defined (_ANSI_SOURCE) || defined (_POSIX_SOURCE))
+  /* why do I have to do this???? */
+struct timeval
+{
+    long tv_sec;                /* seconds */
+    long tv_usec;               /* and microseconds */
 };
+#endif
+
 
 #if ! defined (NSIG)
 #define NSIG 32
@@ -62,7 +108,7 @@ struct endpoint_s
 {
       /* fields for managing multiple reads into the inBuffer. */
     Buffer *inBuffer ;          /* list of buffers to read into */
-    unsigned int inBufferIdx ;         /* where is list we're at. */
+    u_int inBufferIdx ;         /* where is list we're at. */
     size_t inIndex ;            /* where in current read we're at */
     size_t inMinLen ;           /* minimum amount to read */
     size_t inAmtRead ;          /* amount read so far */
@@ -71,7 +117,7 @@ struct endpoint_s
     
       /* fields for managing multiple writes from the outBuffer */
     Buffer *outBuffer ;         /* list of buffers to write */
-    unsigned int outBufferIdx ;        /* index into buffer list to start write */
+    u_int outBufferIdx ;        /* index into buffer list to start write */
     size_t outIndex ;           /* where in current buffer we write from */
     size_t outSize ;            /* total of all the buffers */
     size_t outAmtWritten ;      /* amount written so far */
@@ -110,7 +156,7 @@ extern const char *InputFile ;
 
 static EndPoint mainEndPoint ;
 static bool mainEpIsReg = false ;
-unsigned int stdioFdMax = MAX_STDIO_FD ;
+static u_int stdioFdMax = MAX_STDIO_FD ;
 
 time_t  PrivateTime;
 
@@ -118,7 +164,8 @@ time_t  PrivateTime;
 typedef void (*sigfn) (int) ;
 static sigfn *sigHandlers ;
 
-static volatile sig_atomic_t *sigFlags ;
+/* XXX - should be sig_atomic_t if we have it */
+static VOLATILE int *sigFlags ;
 
 
 
@@ -137,8 +184,8 @@ static void doTimeout (void) ;
 static void handleSignals (void) ;
 
 #if 0
-static int ff_set (fd_set *set, unsigned int start) ;
-static int ff_free (fd_set *set, unsigned int start) ;
+static int ff_set (fd_set *set, u_int start) ;
+static int ff_free (fd_set *set, u_int start) ;
 #endif
 static void endpointCleanup (void) ;
 
@@ -151,8 +198,8 @@ static EndPoint *priorityList ; /* endpoints indexed on priority */
 
 static int absHighestFd = 0 ;       /* never goes down */
 static int highestFd = -1 ;
-static unsigned int endPointCount = 0 ;
-static unsigned int priorityCount = 0 ;
+static u_int endPointCount = 0 ;
+static u_int priorityCount = 0 ;
 
 static fd_set rdSet ;
 static fd_set wrSet ;
@@ -189,14 +236,14 @@ EndPoint newEndPoint (int fd)
 
   /* try to dup the fd to a larger number to leave lower values free for
      broken stdio implementations. */
-  if (stdioFdMax > 0 && ((unsigned int) fd) <= stdioFdMax)
+  if (stdioFdMax > 0 && ((u_int) fd) <= stdioFdMax)
     {
       int newfd = fcntl(fd, F_DUPFD, stdioFdMax + 1);
       if (newfd >= 0)
         {
           d_printf (1,"Dupped fd %d to %d\n",fd,newfd) ;
           if (close (fd) != 0)
-            syswarn ("ME oserr close (%d)", fd) ;
+            syslog (LOG_ERR,CLOSE_FAILED,fd) ;
         }
       else
         {
@@ -207,21 +254,20 @@ EndPoint newEndPoint (int fd)
       fd = newfd ;
     }
 
-  if ((unsigned int) fd >= maxEndPoints)
+  if ((u_int) fd >= maxEndPoints)
     {
-      unsigned int i = maxEndPoints ;
+      u_int i = maxEndPoints ;
       
       maxEndPoints = (((fd + 256) / 256) * 256); /* round up to nearest 256 */ 
       if (endPoints == NULL)
         {
-          endPoints = xmalloc (sizeof(EndPoint) * maxEndPoints) ;
-          priorityList = xmalloc (sizeof(EndPoint) * maxEndPoints) ;
+          endPoints = ALLOC (EndPoint,maxEndPoints) ;
+          priorityList = ALLOC (EndPoint,maxEndPoints) ;
         }
       else
         {
-          endPoints = xrealloc (endPoints,sizeof(EndPoint) * maxEndPoints) ;
-          priorityList = xrealloc (priorityList,
-                                   sizeof(EndPoint) * maxEndPoints) ;
+          endPoints = REALLOC (endPoints,EndPoint,maxEndPoints) ;
+          priorityList = REALLOC (priorityList,EndPoint,maxEndPoints) ;
         }
 
       for ( ; i < maxEndPoints ; i++)
@@ -232,19 +278,21 @@ EndPoint newEndPoint (int fd)
 
   if (fd > absHighestFd)
     {
+      static bool sizelogged = false ;
           
 #if defined (FD_SETSIZE)
-      if ((unsigned int) fd >= FD_SETSIZE)
+      if (fd >= FD_SETSIZE)
         {
-          warn ("ME fd (%d) looks too big (%d -- FD_SETSIZE)", fd,
-                FD_SETSIZE) ;
+          sizelogged = true ;
+          syslog (LOG_ERR,FD_TOO_BIG,fd,FD_SETSIZE,"FD_SETSIZE") ;
           return NULL ;
         }
 #else
       if (fd > (sizeof (fd_set) * CHAR_BIT))
         {
-          warn ("ME fd (%d) looks too big (%d -- sizeof (fd_set) * CHAR_BIT)",
-                fd, (sizeof (fd_set) * CHAR_BIT)) ;
+          sizelogged = true ;
+          syslog (LOG_ERR,FD_TOO_BIG,fd,(sizeof (fd_set) * CHAR_BIT),
+                  "(sizeof (fd_set) * CHAR_BIT)");
           return NULL ;
         }
 #endif
@@ -252,7 +300,8 @@ EndPoint newEndPoint (int fd)
       absHighestFd = fd ;
     }
       
-  ep = xcalloc (1, sizeof(struct endpoint_s)) ;
+  ep = CALLOC (struct endpoint_s, 1) ;
+  ASSERT (ep != NULL) ;
 
   ep->inBuffer = NULL ;
   ep->inBufferIdx = 0 ;
@@ -295,7 +344,7 @@ EndPoint newEndPoint (int fd)
 
 void delEndPoint (EndPoint ep) 
 {
-  unsigned int idx ;
+  u_int idx ;
 
   if (ep == NULL)
     return ;
@@ -321,7 +370,7 @@ void delEndPoint (EndPoint ep)
   /* Adjust the global arrays to account for deleted endpoint. */
   endPoints [ep->myFd] = NULL ;
   if (ep->myFd == highestFd)
-    while (highestFd >= 0 && endPoints [highestFd] == NULL)
+    while (endPoints [highestFd] == NULL && highestFd >= 0)
       highestFd-- ;
 
   for (idx = 0 ; idx < priorityCount ; idx++)
@@ -336,7 +385,7 @@ void delEndPoint (EndPoint ep)
 
   endPointCount-- ;
 
-  free (ep) ;
+  FREE (ep) ;
 }
 
 int endPointFd (EndPoint endp)
@@ -349,19 +398,19 @@ int endPointFd (EndPoint endp)
 
 
 
-/* Request a read to be done next time there's data. The endpoint ENDP
- * is what will do the read. BUFFERS is the array of Buffers the data
- * should go into. FUNC is the callback function to call when the read
- * is complete. CLIENTDATA is the client data to pass back into the
+/* Request a read to be done next time there's data. The endpoint
+ * ENDP is what will do the read. BUFF is the Buffer the data should
+ * go into. FUNC is the callback function to call when the read is
+ * complete. CLIENTDATA is the client data to pass back into the
  * callback function. MINLEN is the minimum amount of data to
- * read. If MINLEN is 0 then then BUFFERS must be filled, otherwise at
+ * read. If MINLEN is 0 then then BUFF must be filled, otherwise at
  * least MINLEN bytes must be read.
  *
- * BUFFERS can be NULL, in which case no read is actually done, but the
+ * BUFF can be null, in which case no read is actually done, but the
  * callback function will be called still. This is useful for
  * listening sockets.
  *
- * Returns 0 if the read couldn't be prepared (for example if a read
+ * Returns 0 if the read couln't be prepared (for example if a read
  * is already outstanding).
  */
 
@@ -404,12 +453,12 @@ int prepareRead (EndPoint endp,
 
 
 
-/* Request a write to be done at a later point. ENDP is the EndPoint to
- * do the write. BUFFERS is the array of Buffers to write from. FUNC is
- * the function to call when the write is complete. CLIENTDATA is some
+/* Request a write to be done at a later point. ENDP is the EndPoint
+ * to do the write. BUFF is the Buffer to write from. FUNC is the
+ * function to call when the write is complete. CLIENTDATA is some
  * data to hand back to the callback function.
  *
- * If BUFFERS is NULL, then no write will actually by done, but the
+ * If BUFF is null, then no write will actually by done, but the
  * callback function will still be called. This is useful for
  * connecting sockets.
  *
@@ -472,8 +521,11 @@ void cancelRead (EndPoint endp)
   copied to buffer. The number of bytes copied (if it is less than *len) is
   copied to len. If no write was outstanding then len will have 0 stored in
   it. */
-void cancelWrite (EndPoint endp, char *buffer UNUSED, size_t *len UNUSED)
+void cancelWrite (EndPoint endp, char *buffer, size_t *len)
 {
+  (void) buffer ;
+  (void) len ;
+  
   FD_CLR (endp->myFd, &wrSet) ;
   if (!FD_ISSET (endp->myFd, &rdSet))
     FD_CLR (endp->myFd, &exSet) ;
@@ -506,8 +558,8 @@ TimeoutId prepareWake (EndpTCB func, time_t timeToWake, void *clientData)
   id = timerElemAdd (timeToWake,func,clientData) ;
 
 #if 0
-  d_printf (1, "Preparing wake %d at date %ld for %ld seconds\n",
-           (int) id, (long) now, (long) (timeToWake - now)) ;
+  d_printf (1,"Preparing wake %d at date %ld for %d seconds\n",
+           (int) id, (long) now, timeToWake - now) ;
 #endif
 
   return id ;
@@ -523,15 +575,15 @@ TimeoutId prepareSleep (EndpTCB func, int timeToSleep, void *clientData)
   id = timerElemAdd (now + timeToSleep,func,clientData) ;
 
 #if 0
-  d_printf (1, "Preparing sleep %d at date %ld for %ld seconds\n",
-           (int) id, (long) now, (long) timeToSleep) ;
+  d_printf (1,"Preparing sleep %d at date %ld for %d seconds\n",
+           (int) id, (long) now, timeToSleep) ;
 #endif
 
   return id ;
 }
 
 
-/* Updates an existing timeout request to go off TIMETOSLEEP seconds from
+/* Updates a an existing timeout request to go off TIMETOSLEEP seconds from
    now, or queues a new request.  Always returns a new ID. */
 TimeoutId updateSleep (TimeoutId tid, EndpTCB func, int timeToSleep,
                        void *clientData) 
@@ -596,7 +648,7 @@ void Run (void)
       struct timeval timeout ;
       struct timeval *twait ;
       int sval ;
-      unsigned int idx ;
+      u_int idx ;
       bool modifiedTime = false ;
       
       twait = getTimeout (&timeout) ;
@@ -624,19 +676,12 @@ void Run (void)
         }
 
       /* calculate host backlog statistics */
-      TMRstart(TMR_BACKLOGSTATS);
       gCalcHostBlStat ();
-      TMRstop(TMR_BACKLOGSTATS);
 
-      TMRstart(TMR_IDLE);
       sval = select (highestFd + 1, &rSet, &wSet, &eSet, twait) ;
-      TMRstop(TMR_IDLE);
 
       timePasses () ;
-      if (innconf->timer != 0 && TMRnow() > innconf->timer * 1000) {
-          TMRsummary ("ME", timer_name);
-      }
-
+      
       if (sval == 0 && twait == NULL)
         die ("No fd's ready and no timeouts") ;
       else if (sval < 0 && errno == EINTR)
@@ -645,7 +690,7 @@ void Run (void)
         }
       else if (sval < 0) 
         {
-          syswarn ("ME exception: select failed: %d", sval) ;
+          syslog (LOG_ERR,BAD_SELECT,sval) ;
           stopRun () ;
         }
       else if (sval > 0)
@@ -714,8 +759,7 @@ void Run (void)
                             }
                           else if (sval < 0)
                             {
-                              syswarn ("ME exception: select failed: %d",
-                                       sval) ;
+                              syslog (LOG_ERR,BAD_SELECT,sval) ;
                               stopRun () ;
                               return ;
                             }
@@ -843,9 +887,7 @@ void Run (void)
 
                     ep->workCbk = NULL ;
                     ep->workData = NULL ;
-                    TMRstart(TMR_CALLBACK);
                     func (ep,data) ;
-                    TMRstop(TMR_CALLBACK);
                   }
               
             }
@@ -930,27 +972,29 @@ void freeTimeoutQueue (void)
 static IoStatus doRead (EndPoint endp) 
 {
   int i = 0 ;
-  unsigned int idx ;
-  unsigned int bCount = 0 ;
+  u_int idx ;
+  u_int bCount = 0 ;
   struct iovec *vp = NULL ;
   Buffer *buffers = endp->inBuffer ;
-  unsigned int currIdx = endp->inBufferIdx ;
+  u_int currIdx = endp->inBufferIdx ;
   size_t amt = 0 ;
   IoStatus rval = IoIncomplete ;
 
-  TMRstart(TMR_READ);
   for (i = currIdx ; buffers && buffers [i] != NULL ; i++)
     bCount++ ;
 
   bCount = (bCount > IOV_MAX ? IOV_MAX : bCount) ;
 
+  i = 0 ;
+
   /* now set up the iovecs for the readv */
   if (bCount > 0)
     {
       char *bbase ;
       size_t bds, bs ;
 
-      vp = xcalloc (bCount, sizeof(struct iovec)) ;
+      vp = CALLOC (struct iovec, bCount) ;
+      ASSERT (vp != NULL) ;
 
       bbase = bufferBase (buffers[currIdx]) ;
       bds = bufferDataSize (buffers[currIdx]) ;
@@ -983,7 +1027,7 @@ static IoStatus doRead (EndPoint endp)
           endp->inAmtRead += readAmt ;
           
           /* check if we filled the first buffer */
-          if (readAmt >= (size_t) vp[0].iov_len)
+          if (readAmt >= vp[0].iov_len)
             {                   /* we did */
               bufferIncrDataSize (buffers[currIdx], vp[0].iov_len) ;
               readAmt -= vp [0].iov_len ;
@@ -1040,35 +1084,38 @@ static IoStatus doRead (EndPoint endp)
       else                   /* i < 0 && errno == EAGAIN */
         rval = IoIncomplete ;
       
-      free (vp) ;
+      FREE (vp) ;
     }
   else
     rval = IoDone ;
-  TMRstop(TMR_READ);
+  
   return rval ;
 }
 
 /* called when the file descriptor on the endpoint is write ready. */
 static IoStatus doWrite (EndPoint endp)
 {
-  unsigned int idx ;
+  u_int idx ;
   int i = 0 ;
   size_t amt = 0 ;
-  unsigned int bCount = 0 ;
+  u_int bCount = 0 ;
   struct iovec *vp = NULL ;
   Buffer *buffers = endp->outBuffer ;
-  unsigned int currIdx = endp->outBufferIdx ;
+  u_int currIdx = endp->outBufferIdx ;
   IoStatus rval = IoIncomplete ;
   
-  TMRstart(TMR_WRITE);
   for (i = currIdx ; buffers && buffers [i] != NULL ; i++)
     bCount++ ;
 
   bCount = (bCount > IOV_MAX ? IOV_MAX : bCount) ;
 
+  i = 0 ;
+  
   if (bCount > 0)
     {
-      vp = xcalloc (bCount, sizeof(struct iovec)) ;
+      vp = CALLOC (struct iovec, bCount) ;
+      ASSERT (vp != NULL) ;
+
 
       vp[0].iov_base = bufferBase (buffers [currIdx]) ;
       vp[0].iov_base = (char *) vp[0].iov_base + endp->outIndex ;
@@ -1109,7 +1156,7 @@ static IoStatus doWrite (EndPoint endp)
           /* now figure out which buffers got completely written */
           for (idx = 0 ; writeAmt > 0 ; idx++)
             {
-              if (writeAmt >= (size_t) vp[idx].iov_len)
+              if (writeAmt >= vp [idx].iov_len)
                 {
                   endp->outBufferIdx++ ;
                   endp->outIndex = 0 ;
@@ -1144,12 +1191,11 @@ static IoStatus doWrite (EndPoint endp)
       else
         d_printf (1,"Wrote 0 bytes in doWrite()?\n") ;
 
-      free (vp) ;
+      FREE (vp) ;
     }
   else
     rval = IoDone ;
 
-  TMRstop(TMR_WRITE);
   return rval ;
 }
 
@@ -1157,19 +1203,19 @@ static IoStatus doWrite (EndPoint endp)
 static IoStatus doExcept (EndPoint endp)
 {
   int optval;
-  socklen_t size ;
+  ARGTYPE size ;
   int fd = endPointFd (endp) ;
 
   if (getsockopt (fd, SOL_SOCKET, SO_ERROR,
                   (char *) &optval, &size) != 0)
-    syswarn ("ME exception: getsockopt (%d)", fd) ;
+    syslog (LOG_ERR,GETSOCKOPT_FAILURE,fd) ;
   else if (optval != 0)
     {
       errno = optval ;
-      syswarn ("ME exception: fd %d", fd) ;
+      syslog (LOG_ERR,EXCEPTION_NOTICE,fd) ;
     }
   else
-    syswarn ("ME exception: fd %d: Unknown error", fd) ;
+    syslog (LOG_ERR,UNKNOWN_EXCEPTION,fd) ;
 
 #if 0
   sleep (5) ;
@@ -1206,8 +1252,8 @@ static void pipeHandler (int s)
    endpoints on their relative activity */
 static int hitCompare (const void *v1, const void *v2)
 {
-  const struct endpoint_s *e1 = *((const struct endpoint_s * const *) v1) ;
-  const struct endpoint_s *e2 = *((const struct endpoint_s * const *) v2) ;
+  const EndPoint e1 = *((const EndPoint *) v1) ;
+  const EndPoint e2 = *((const EndPoint *) v2) ;
   double e1Hit = e1->selectHits ;
   double e2Hit = e2->selectHits ;
 
@@ -1230,7 +1276,7 @@ static int hitCompare (const void *v1, const void *v2)
    active endpoints. */
 static void reorderPriorityList (void)
 {
-  unsigned int i, j ;
+  int i, j ;
   static int thisTime = 4;
 
   /* only sort every 4th time since it's so expensive */
@@ -1265,12 +1311,13 @@ static TimerElem newTimerElem (TimeoutId i, time_t w, EndpTCB f, void *d)
 
   if (timeoutPool == NULL)
     {
-      unsigned int j ;
+      int i ;
 
-      timeoutPool = xmalloc (sizeof(TimerElemStruct) * TIMEOUT_POOL_SIZE) ;
+      timeoutPool = ALLOC (TimerElemStruct, TIMEOUT_POOL_SIZE) ;
+      ASSERT (timeoutPool != NULL) ;
 
-      for (j = 0; j < TIMEOUT_POOL_SIZE - 1; j++)
-        timeoutPool[j] . next = &(timeoutPool [j + 1]) ;
+      for (i = 0; i < TIMEOUT_POOL_SIZE - 1; i++)
+        timeoutPool[i] . next = &(timeoutPool [i + 1]) ;
       timeoutPool [TIMEOUT_POOL_SIZE-1] . next = NULL ;
     }
 
@@ -1383,11 +1430,27 @@ static void doTimeout (void)
 
 
 
+
 #if defined (WANT_MAIN)
 
+
+#include <netinet/in.h>
+#include <arpa/inet.h>
+#include <sys/socket.h>
+#include <string.h>
+
 #define BUFF_SIZE 100
 
-static void lineIsWritten (EndPoint ep, IoStatus status, Buffer *buffers, void *d UNUSED)
+
+void timerCallback (void *cd) ;
+void timerCallback (void *cd)
+{
+  d_printf (1,"Callback \n") ;
+}
+
+  
+void lineIsWritten (EndPoint ep, IoStatus status, Buffer *buffer, void *data);
+void lineIsWritten (EndPoint ep, IoStatus status, Buffer *buffer, void *data)
 {
   int i ;
   
@@ -1402,12 +1465,12 @@ static void lineIsWritten (EndPoint ep, IoStatus status, Buffer *buffers, void *
       errno = oldErrno ;
     }
 
-  for (i = 0 ; buffers && buffers[i] ; i++) {
-    delBuffer (buffers[i]);
-  }
+  for (i = 0 ; buffer && buffer [i] ; i++)
+    delBuffer (buffer [i]) ;
 }
 
-static void lineIsRead (EndPoint myEp, IoStatus status, Buffer *buffers, void *d UNUSED)
+void lineIsRead (EndPoint myEp, IoStatus status, Buffer *buffer, void *data);
+void lineIsRead (EndPoint myEp, IoStatus status, Buffer *buffer, void *d)
 {
   Buffer *writeBuffers, *readBuffers ;
   Buffer newBuff1, newBuff2 ;
@@ -1434,13 +1497,13 @@ static void lineIsRead (EndPoint myEp, IoStatus status, Buffer *buffers, void *d
     }
   
   
-  data = bufferBase (buffers[0]);
-  len = bufferDataSize (buffers[0]);
+  data = bufferBase (buffer[0]) ;
+  len = bufferDataSize (buffer[0]) ;
   
   if (data [len - 1] == '\r' || data [len - 1] == '\n')
-    bufferDecrDataSize (buffers[0], 1);
+    bufferDecrDataSize (buffer [0],1) ;
   if (data [len - 1] == '\r' || data [len - 1] == '\n')
-    bufferDecrDataSize (buffers[0], 1);
+    bufferDecrDataSize (buffer [0],1) ;
 
   data [len] = '\0' ;
   
@@ -1451,29 +1514,34 @@ static void lineIsRead (EndPoint myEp, IoStatus status, Buffer *buffers, void *d
   newInputBuffer = newBuffer (BUFF_SIZE) ;
   
   p = bufferBase (newBuff1) ; 
-  strlcpy (p, "Thanks for that \"", bufferSize (newBuff1)) ;
+  strcpy (p, "Thanks for that \"") ;
   bufferSetDataSize (newBuff1,strlen (p)) ;
   
   p = bufferBase (newBuff2) ;
-  strlcpy (p,"\" very tasty\n", bufferSize (newBuff2)) ;
+  strcpy (p,"\" very tasty\n") ;
   bufferSetDataSize (newBuff2,strlen (p)) ;
 
-  writeBuffers = makeBufferArray (newBuff1, buffers[0], newBuff2, NULL);
+  writeBuffers = makeBufferArray (newBuff1,buffer[0],newBuff2,NULL) ;
   readBuffers = makeBufferArray (newInputBuffer,NULL) ;
   
-  prepareWrite(myEp, writeBuffers, NULL, lineIsWritten, NULL);
-  prepareRead(myEp, readBuffers, lineIsRead, NULL, 1);
+  prepareWrite (myEp,writeBuffers,lineIsWritten,NULL) ;
+  prepareRead (myEp,readBuffers,lineIsRead,NULL,1) ;
+
+#if 0
+  myEp->registerWake (&timerCallback,theTime() + 7,0) ;
+#endif
 }
 
 
+static void printDate (TimeoutId tid, void *data) ;
 static void printDate (TimeoutId tid, void *data)
 {
-  char dateString[30];
-  const time_t t = theTime() ;
+  time_t t ;
 
-  timeToString (t, dateString, sizeof (dateString)) ;
-  d_printf (1,"Timeout (%d) time now is %ld %s\n",
-            (int) tid, (long) t, dateString) ;
+  t = theTime() ;
+  
+  d_printf (1,"Timeout (%d) time now is %ld %s",
+           (int) tid,(long) t,ctime(&t)) ;
 
   if (timeoutQueue == NULL) 
     {
@@ -1485,13 +1553,13 @@ static void printDate (TimeoutId tid, void *data)
 
 TimeoutId rm ;
 
+static void Timeout (TimeoutId tid, void *data) ;
 static void Timeout (TimeoutId tid, void *data)
 {
   static int seeded ;
   static int howMany ;
   static int i ;
-  char dateString[30];
-  const time_t t = theTime() ;
+  time_t t = theTime() ;
 
   if ( !seeded )
     {
@@ -1499,10 +1567,9 @@ static void Timeout (TimeoutId tid, void *data)
       seeded = 1 ;
     }
 
-  timeToString (t, dateString, sizeof (dateString)) ;
-  d_printf (1,"Timeout (%d) time now is %ld %s\n",
-            (int) tid, (long) t, dateString) ;
-
+  d_printf (1,"Timeout (%d) time now is %ld %s",
+           (int) tid, (long) t,ctime(&t)) ;
+  
   if (timeoutQueue != NULL && timeoutQueue->next != NULL)
     d_printf (1,"%s timeout id %d\n",
              (removeTimeout (rm) ? "REMOVED" : "FAILED TO REMOVE"), rm) ;
@@ -1524,13 +1591,14 @@ static void Timeout (TimeoutId tid, void *data)
 }
 
 
-static void newConn (EndPoint ep, IoStatus status UNUSED, Buffer *buffers UNUSED, void *d UNUSED)
+void newConn (EndPoint ep, IoStatus status, Buffer *buffer, void *d) ;
+void newConn (EndPoint ep, IoStatus status, Buffer *buffer, void *d)
 {
   EndPoint newEp ;
   struct sockaddr_in in ;
   Buffer *readBuffers ;
   Buffer newBuff = newBuffer (BUFF_SIZE) ;
-  socklen_t len = sizeof (in);
+  int len = sizeof (in) ;
   int fd ;
 
   memset (&in, 0, sizeof (in)) ;
@@ -1545,11 +1613,11 @@ static void newConn (EndPoint ep, IoStatus status UNUSED, Buffer *buffers UNUSED
   
   newEp = newEndPoint (fd) ;
 
-  prepareRead(ep, NULL, newConn, NULL, 0);
+  prepareRead (ep, NULL, newConn,NULL,0) ;
 
   readBuffers = makeBufferArray (newBuff,NULL) ;
 
-  prepareRead(newEp, readBuffers, lineIsRead, NULL, 1);
+  prepareRead (newEp, readBuffers, lineIsRead, NULL, 1) ;
 
   d_printf (1,"Set up a new connection\n");
 }
@@ -1560,11 +1628,11 @@ int main (int argc, char **argv)
   EndPoint accConn ;
   struct sockaddr_in accNet ;
   int accFd = socket (AF_INET,SOCK_STREAM,0) ;
-  unsigned short port = atoi (argc > 1 ? argv[1] : "10000") ;
+  u_short port = atoi (argc > 1 ? argv[1] : "10000") ;
   time_t t = theTime() ;
 
 
-  char * program = strrchr (argv[0],'/') ;
+  program = strrchr (argv[0],'/') ;
 
   if (!program)
     program = argv [0] ;
@@ -1594,7 +1662,7 @@ int main (int argc, char **argv)
   
   accConn = newEndPoint (accFd) ;
 
-  prepareRead(accConn, NULL, newConn, NULL, 0);
+  prepareRead (accConn,NULL,newConn,NULL,0) ;
 
   prepareSleep (Timeout,5,(void *) 0x10) ;
 
@@ -1612,12 +1680,12 @@ int main (int argc, char **argv)
 /* Probably doesn't do the right thing for SIGCHLD */
 void setSigHandler (int signum, void (*ptr)(int))
 {
-  unsigned int i ;
+  u_int i ;
 
   if (sigHandlers == NULL)
     {
-      sigHandlers = xmalloc (sizeof(sigfn) * NSIG) ;
-      sigFlags = xmalloc (sizeof(sig_atomic_t) * NSIG) ;
+      sigHandlers = ALLOC (sigfn,NSIG) ;
+      sigFlags = ALLOC (int,NSIG) ;
       for (i = 0 ; i < NSIG ; i++)
         {
           sigHandlers [i] = NULL ;
@@ -1641,18 +1709,31 @@ void setSigHandler (int signum, void (*ptr)(int))
 static void handleSignals (void)
 {
   int i ;
+#if defined(USE_SIGVEC)
+  int mask ;
+#endif
 
   for (i = 1; i < NSIG; i++)
     {
       if (sigFlags[i])
         {
-#if defined(HAVE_SIGACTION)
+#if defined(USE_SIGACTION)
           sigset_t set, oset ;
       
           if (sigemptyset (&set) != 0 || sigaddset (&set, i) != 0)
             die ("sigemptyset or sigaddset failed") ;
           if (sigprocmask (SIG_BLOCK, &set, &oset) != 0)
             die ("sigprocmask failed: %s", strerror(errno)) ;
+#elif defined(USE_SIGVEC)
+# ifndef sigmask
+#  define sigmask(s)    (1 << ((s) - 1))
+# endif
+          int mask ;
+          
+          mask = sigblock (sigmask(i)) ;
+#elif defined(USE_SIGSET)
+          if (sighold (i) != 0)
+            die ("sighold failed: %s", strerror(errno)) ;
 #else
       /* hope for the best */
 #endif
@@ -1664,9 +1745,14 @@ static void handleSignals (void)
               sigHandlers[i] != SIG_DFL)
             (sigHandlers[i])(i) ;
             
-#if defined(HAVE_SIGACTION)
+#if defined(USE_SIGACTION)
           if (sigprocmask (SIG_SETMASK, &oset, (sigset_t *)NULL) != 0)
             die ("sigprocmask failed: %s", strerror(errno)) ;
+#elif defined(USE_SIGVEC)
+          (void) sigsetmask (mask) ;
+#elif defined(USE_SIGSET)
+          if (sigrelse (i) != 0)
+            die ("sigrelse failed: %s", strerror(errno)) ;
 #else
           /* hope for the best */
 #endif
@@ -1698,10 +1784,7 @@ int endpointConfigLoadCbk (void *data)
 
       if (stdioFdMax > FD_SETSIZE)
         {
-          logOrPrint (LOG_ERR,fp,
-                      "ME config: value of %s (%ld) in %s is higher"
-                      " than maximum of %ld. Using %ld","stdio-fdmax",
-                      ival,"global scope",
+          logOrPrint (LOG_ERR,fp,INT_TO_HIGH,"stdio-fdmax",ival,"global scope",
                       (long) FD_SETSIZE, (long) FD_SETSIZE) ;
           stdioFdMax = FD_SETSIZE ;
           rval = 0 ;
@@ -1721,9 +1804,9 @@ int endpointConfigLoadCbk (void *data)
 #if 0
 /* definitely not the fastest, but the most portable way to find the first
   set bit in a mask  */
-static int ff_set (fd_set *set,unsigned int start)
+static int ff_set (fd_set *set,u_int start)
 {
-  unsigned int i ;
+  u_int i ;
 
   for (i = start ; i < FD_SETSIZE ; i++)
     if (FD_ISSET (i,set))
@@ -1733,9 +1816,9 @@ static int ff_set (fd_set *set,unsigned int start)
 }
 
 
-static int ff_free (fd_set *set, unsigned int start)
+static int ff_free (fd_set *set, u_int start)
 {
-  unsigned int i ;
+  u_int i ;
 
   for (i = start ; i < FD_SETSIZE ; i++)
     if (!FD_ISSET (i,set))
@@ -1749,10 +1832,7 @@ static int ff_free (fd_set *set, unsigned int start)
 
 static void endpointCleanup (void)
 {
-  free (endPoints) ;
-  free (priorityList) ;
-  free (sigHandlers) ;
-  endPoints = NULL ;
-  priorityList = NULL ;
-  sigHandlers = NULL ;
+  FREE (endPoints) ;
+  FREE (priorityList) ;
+  FREE (sigHandlers) ;
 }
