@@ -1,9 +1,39 @@
-/*  $Id: innlistener.c 10152 2017-06-05 12:27:29Z iulius $
-**
-**  The implementation of the innfeed InnListener class.
-**
-**  Written by James Brister <brister@vix.com>
-*/
+/* -*- c -*-
+ *
+ * Author:      James Brister <brister@vix.com> -- berkeley-unix --
+ * Start Date:  Thu Dec 28 13:15:04 1995
+ * Project:     INN (innfeed)
+ * File:        innlistener.c
+ * RCSId:       $Id: innlistener.c,v 1.16.2.1 2000/06/08 10:07:20 rra Exp $
+ *
+ * Copyright:   Copyright (c) 1996 by Internet Software Consortium
+ *
+ *              Permission to use, copy, modify, and distribute this
+ *              software for any purpose with or without fee is hereby
+ *              granted, provided that the above copyright notice and this
+ *              permission notice appear in all copies.
+ *
+ *              THE SOFTWARE IS PROVIDED "AS IS" AND INTERNET SOFTWARE
+ *              CONSORTIUM DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
+ *              SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+ *              MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL INTERNET
+ *              SOFTWARE CONSORTIUM BE LIABLE FOR ANY SPECIAL, DIRECT,
+ *              INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+ *              WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ *              WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
+ *              TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE
+ *              USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * Description: Implementation of the InnListener class.
+ * 
+ */
+
+#if ! defined (lint)
+static const char *rcsid = "$Id: innlistener.c,v 1.16.2.1 2000/06/08 10:07:20 rra Exp $" ;
+static void use_rcsid (const char *rid) {   /* Never called */
+  use_rcsid (rcsid) ; use_rcsid (rid) ;
+}
+#endif
 
 #include "innfeed.h"
 #include "config.h"
@@ -12,13 +42,12 @@
 #include <assert.h>
 #include <ctype.h>
 #include <errno.h>
-#include <fcntl.h>
 #include <syslog.h>
 #include <time.h>
 
-#include "inn/libinn.h"
-#include "inn/messages.h"
-#include "inn/nntp.h"
+#ifdef HAVE_FCNTL_H
+# include <fcntl.h>
+#endif
 
 #include "article.h"
 #include "buffer.h"
@@ -26,6 +55,8 @@
 #include "endpoint.h"
 #include "host.h"
 #include "innlistener.h"
+#include "msgs.h"
+#include "nntp.h"
 #include "tape.h"
 
 #define LISTENER_INPUT_BUFFER (1024 * 8) /* byte size of the input buffer */
@@ -45,7 +76,7 @@ struct innlistener_s
     InnListener next ;
 };
 
-static unsigned int listenerCount = 0 ;
+static u_int listenerCount = 0 ;
 static InnListener listenerList = NULL ;
 
 InnListener mainListener ;
@@ -54,7 +85,7 @@ static FILE *droppedFp = NULL ;
 static long droppedCount = 0 ;
 static int droppedFileCount = 0 ;
 static char *dropArtFile = NULL ;
-bool fastExit = false ;
+static bool fastExit = false ;
 
 extern const char *pidFile ;
 extern const char *InputFile ;
@@ -77,7 +108,7 @@ static bool inited = false ;
 void listenerLogStatus (FILE *fp)
 {
   fprintf (fp,"%sListener Status:%s\n",
-           genHtml ? "<B>" : "", genHtml ? "</B>" : "") ;
+           genHtml ? "<H2>" : "", genHtml ? "</H2>" : "") ;
   fprintf (fp,"    Dropped article file: %s\n",dropArtFile) ;
   fprintf (fp,"   Dropped article count: %ld\n",(long) droppedCount) ;
   fprintf (fp,"\n") ;
@@ -85,7 +116,7 @@ void listenerLogStatus (FILE *fp)
 
 InnListener newListener (EndPoint endp, bool isDummy, bool dynamicPeers)
 {
-  InnListener l = xcalloc (1, sizeof(struct innlistener_s)) ;
+  InnListener l = CALLOC (struct innlistener_s, 1) ;
   Buffer *readArray ;
 
   if (!inited)
@@ -94,10 +125,13 @@ InnListener newListener (EndPoint endp, bool isDummy, bool dynamicPeers)
       atexit (listenerCleanup) ;
     }
   
+  ASSERT (l != NULL) ;
+
   l->myep = endp ;
 
   l->hostLen = MAX_HOSTS ;
-  l->myHosts = xcalloc (l->hostLen, sizeof(Host)) ;
+  l->myHosts = CALLOC (Host, l->hostLen) ;
+  ASSERT (l->myHosts != NULL) ;
 
   l->inputBuffer = newBuffer (LISTENER_INPUT_BUFFER) ;
   l->dummyListener = isDummy ;
@@ -118,18 +152,18 @@ InnListener newListener (EndPoint endp, bool isDummy, bool dynamicPeers)
   return l ;
 }
 
-void gPrintListenerInfo (FILE *fp, unsigned int indentAmt)
+void gPrintListenerInfo (FILE *fp, u_int indentAmt)
 {
   InnListener p ;
   char indent [INDENT_BUFFER_SIZE] ;
-  unsigned int i ;
+  u_int i ;
   
   for (i = 0 ; i < MIN(INDENT_BUFFER_SIZE - 1,indentAmt) ; i++)
     indent [i] = ' ' ;
   indent [i] = '\0' ;
 
-  fprintf (fp,"%sGlobal InnListener list : %p (count %u) {\n",
-           indent,(void *) listenerList,listenerCount) ;
+  fprintf (fp,"%sGlobal InnListener list : %p (count %d) {\n",
+           indent,listenerList,listenerCount) ;
   for (p = listenerList ; p != NULL ; p = p->next)
     printListenerInfo (p,fp,indentAmt + INDENT_INCR) ;
   fprintf (fp,"%s}\n",indent) ;
@@ -137,17 +171,17 @@ void gPrintListenerInfo (FILE *fp, unsigned int indentAmt)
 
 
 
-void printListenerInfo (InnListener listener, FILE *fp, unsigned int indentAmt)
+void printListenerInfo (InnListener listener, FILE *fp, u_int indentAmt)
 {
   char indent [INDENT_BUFFER_SIZE] ;
-  unsigned int i ;
+  u_int i ;
   
   for (i = 0 ; i < MIN(INDENT_BUFFER_SIZE - 1,indentAmt) ; i++)
     indent [i] = ' ' ;
   indent [i] = '\0' ;
 
-  fprintf (fp,"%sInnListener : %p {\n",indent,(void *) listener) ;
-  fprintf (fp,"%s    endpoint : %p\n", indent,(void *) listener->myep) ;
+  fprintf (fp,"%sInnListener : %p {\n",indent,listener) ;
+  fprintf (fp,"%s    endpoint : %p\n", indent, listener->myep) ;
   fprintf (fp,"%s    dummy-listener : %s\n",indent,
            boolToString (listener->dummyListener)) ;
   fprintf (fp,"%s    dynamicPeers : %s\n",indent,
@@ -164,7 +198,7 @@ void printListenerInfo (InnListener listener, FILE *fp, unsigned int indentAmt)
       if (listener->myHosts [i] != NULL)
         printHostInfo (listener->myHosts [i],fp,indentAmt + INDENT_INCR) ;
 #else
-      fprintf (fp,"%s        %p\n",indent,(void *) listener->myHosts[i]) ;
+      fprintf (fp,"%s        %p\n",indent,listener->myHosts[i]) ;
 #endif
     }
   
@@ -192,8 +226,8 @@ static void unlinkPidFile (void)
      Listener will be deleted. */
 void shutDown (InnListener l)
 {
-  unsigned int i ;
-  unsigned int count ;
+  u_int i ;
+  u_int count ;
 
   d_printf (1,"Shutting down the listener\n") ;
 
@@ -230,12 +264,13 @@ void shutDown (InnListener l)
       char dateString [30] ;
 
       gHostStats();
-      timeToString (now, dateString, sizeof (dateString)) ;
+      strcpy (dateString,ctime (&now)) ;
+      dateString [24] = '\0' ;
 
       if (fastExit)
-        notice ("ME finishing (quickly) at %s", dateString) ;
+        syslog (LOG_NOTICE,FAST_EXIT_PROGRAM,dateString) ;
       else
-        notice ("ME finishing at %s", dateString) ;
+        syslog (LOG_NOTICE,STOPPING_PROGRAM,dateString) ;
 
       unlinkPidFile();
       exit (0) ;
@@ -245,7 +280,7 @@ void shutDown (InnListener l)
 
 bool listenerAddPeer (InnListener listener, Host hostObj)
 {
-  unsigned int i ;
+  u_int i ;
 
   d_printf (1,"Adding peer: %s\n", hostPeerName (hostObj)) ;
   
@@ -270,10 +305,10 @@ bool listenerIsDummy (InnListener listener)
 }
 
 /* Called by the Host when it (the Host) is about to delete itself. */
-unsigned int listenerHostGone (InnListener listener, Host host)
+u_int listenerHostGone (InnListener listener, Host host)
 {
-  unsigned int i ;
-  unsigned int someThere = 0 ;
+  u_int i ;
+  u_int someThere = 0 ;
 
   d_printf (1,"Host is gone: %s\n", hostPeerName (host)) ;
   
@@ -323,7 +358,7 @@ void openInputFile (void)
     {
       if (dup2(fd, mainFd) < 0)
 	die ("dup2 %d %d: %s\n", fd, mainFd, strerror(errno)) ;
-      close (fd);
+      (void) close (fd);
     }
 
   i = read(mainFd, buf, sizeof (buf)) ;
@@ -337,16 +372,18 @@ void openInputFile (void)
       if (offset > 0 && *p == '\n')
 	lseek (mainFd, offset, SEEK_SET) ;
       else
-	lseek (mainFd, 0, SEEK_SET) ;
+	lseek (mainFd, (OFFSET_T)0, SEEK_SET) ;
     }
   syslog(LOG_NOTICE, "ME opened %s", InputFile);
 }
 
 
-int listenerConfigLoadCbk (void *data UNUSED)
+int listenerConfigLoadCbk (void *data)
 {
   int bval ;
 
+  (void) data ;
+
   if (getBool (topScope,"fast-exit",&bval,NO_INHERIT))
     fastExit = (bval ? true : false) ;
 
@@ -400,7 +437,7 @@ static void newArticleCommand (EndPoint ep, IoStatus i,
       else 
         {
           d_printf (1,"Got EOF on listener\n") ;
-          notice ("ME source lost . Exiting");
+          syslog (LOG_NOTICE,INN_GONE) ;
 	  shutDown (lis) ;
         }
     }
@@ -410,7 +447,7 @@ static void newArticleCommand (EndPoint ep, IoStatus i,
 #if HAVE_SOCKETPAIR
       if (errno != ECONNABORTED)
 #endif
-      syswarn ("ME source read error, exiting") ;
+      syslog (LOG_CRIT,INN_IO_ERROR) ;
       d_printf (1,"Got IO Error on listener\n") ;
       shutDown (lis) ;
     }
@@ -420,21 +457,21 @@ static void newArticleCommand (EndPoint ep, IoStatus i,
          precede the newline, we never get out of here */
       if (strlen(bbase) < blen)
         {
-          warn ("ME source format bad, exiting: %s", bbase) ;
+          syslog (LOG_CRIT,INN_BAD_CMD,bbase) ;
           shutDown (lis) ;
 
           return ;
         }
       if (blen == bufferSize(buffs [0])) {
         if (!expandBuffer (buffs [0], BUFFER_EXPAND_AMOUNT)) {
-          warn ("ME error expanding input buffer") ;
+          syslog (LOG_CRIT,L_BUFFER_EXPAND_ERROR);
           shutDown (lis) ;
           return ;
         }
       }
       readArray = makeBufferArray (bufferTakeRef (buffs [0]),NULL) ;
       if (!prepareRead (ep, readArray, newArticleCommand, data, 1)) {
-        warn ("ME error prepare read failed") ;
+        syslog (LOG_CRIT,L_PREPARE_READ_FAILED) ;
         freeBufferArray (readArray) ;
         shutDown (lis) ;
         return ;
@@ -462,7 +499,7 @@ static void newArticleCommand (EndPoint ep, IoStatus i,
 	     by newline, we may skip a large chunk without noticing */
 	  if (*next == '\0' && next < bbase + blen)
             {
-              warn ("ME source format bad, exiting: %s", cmd) ;
+              syslog (LOG_CRIT,INN_BAD_CMD,cmd) ;
               shutDown (lis) ;
 
               return ;
@@ -473,7 +510,7 @@ static void newArticleCommand (EndPoint ep, IoStatus i,
           /* pick out the leading string (the filename) */
           if ((fileName = findNonBlankString (cmd,&fileNameEnd)) == NULL)
             {
-              warn ("ME source format bad, exiting: %s", cmd) ;
+              syslog (LOG_CRIT,INN_BAD_CMD,cmd) ;
               shutDown (lis) ;
 
               return ;
@@ -485,7 +522,7 @@ static void newArticleCommand (EndPoint ep, IoStatus i,
           if ((msgid = findNonBlankString (fileNameEnd + 1,&msgidEnd)) == NULL)
             {
               *fileNameEnd = ' ' ; /* to make syslog work properly */
-              warn ("ME source format bad, exiting: %s", cmd) ;
+              syslog (LOG_CRIT,INN_BAD_CMD,cmd) ;
               shutDown (lis) ;
 
               return ;
@@ -499,16 +536,15 @@ static void newArticleCommand (EndPoint ep, IoStatus i,
           *fileNameEnd = ' ' ;
 
           /* Check the message ID length */
-          if (strlen(msgid) > NNTP_MAXLEN_MSGID) {
-            warn ("ME message id exceeds limit of %d octets: %s",
-                  NNTP_MAXLEN_MSGID, msgid) ;
+          if (strlen(msgid) > NNTP_MSGID_MAXLEN) {
+            syslog(LOG_ERR,INN_MSGID_SIZE,NNTP_MSGID_MAXLEN,msgid) ;
             *(msgidEnd+1) = '\0' ;
           }
           *msgidEnd = ' ' ;
 
           /* Check if message ID starts with < and ends with > */
           if (*msgid != '<' || *(msgidEnd-1) != '>') {
-            warn ("ME source format bad, exiting: %s", cmd) ;
+            syslog(LOG_ERR,INN_BAD_CMD,cmd);
             *(msgidEnd+1) = '\0';
           }
 
@@ -526,10 +562,10 @@ static void newArticleCommand (EndPoint ep, IoStatus i,
               
               /* See if this is a valid peername */
               for(s = peer; *s; s++)
-                if (!isalnum((unsigned char) *s) && *s != '.' && *s != '-' && *s != '_')
+                if (!isalnum(*s) && *s != '.' && *s != '-' && *s != '_')
                   break;
               if (*s != 0) {
-                  warn ("ME invalid peername %s", peer) ;
+                  syslog(LOG_ERR,INVALID_PEER,peer);
                   continue;
               }
               if (article != NULL)
@@ -555,7 +591,7 @@ static void newArticleCommand (EndPoint ep, IoStatus i,
       if (*cmd != '\0')         /* partial command left in buffer */
         {
           Buffer *bArr ;
-          unsigned int leftAmt = blen - (cmd - bbase) ;
+          u_int leftAmt = blen - (cmd - bbase) ;
 
           ASSERT (cmd != bbase) ;
           /* first we shift whats left in the buffer down to the bottom */
@@ -566,7 +602,7 @@ static void newArticleCommand (EndPoint ep, IoStatus i,
       
           if ( !prepareRead (lis->myep, bArr, newArticleCommand, lis, 1) )
             {
-              warn ("ME error prepare read failed") ;
+              syslog (LOG_CRIT,L_PREPARE_READ_FAILED) ;
 
               freeBufferArray (bArr) ;
               
@@ -583,7 +619,7 @@ static void newArticleCommand (EndPoint ep, IoStatus i,
       
           if ( !prepareRead (lis->myep, bArr, newArticleCommand, lis, 1) )
             {
-              warn ("ME error prepare read failed") ;
+              syslog (LOG_CRIT,L_PREPARE_READ_FAILED) ;
 
               shutDown (lis) ;
 
@@ -615,7 +651,7 @@ static void wakeUp (TimeoutId id, void *data)
 static void giveArticleToPeer (InnListener lis,
                                Article article, const char *peerName)
 {
-  unsigned int i ;
+  u_int i ;
 
   for (i = 0 ; i < lis->hostLen ; i++)
     if (lis->myHosts[i] != NULL)
@@ -649,8 +685,7 @@ static void giveArticleToPeer (InnListener lis,
             {
               /* XXX need to remember we've gone over the limit and not try
                  to add any more. */
-              warn ("ME internal too many hosts. (max is %lu)",
-                    (unsigned long) lis->hostLen) ;
+              syslog (LOG_ERR, TOO_MANY_HOSTS, lis->hostLen) ;
               dropArticle (peerName,article) ;
             }
           else
@@ -669,20 +704,19 @@ static void giveArticleToPeer (InnListener lis,
 
 static void writeCheckPoint (int offsetAdjust)
 {
-  char offsetString[21]; /* size of long long may be 20 */
-  char *writePointer;
+  char offsetString[16], *writePointer ;
   off_t offset ;
   int writeBytes, writeReturn, mainFd ;
 	      
   mainFd = getMainEndPointFd() ;
-  offset = lseek (mainFd, 0, SEEK_CUR) ;
+  offset = lseek (mainFd, (OFFSET_T)0, SEEK_CUR) ;
   if (offset < 0)
     syslog (LOG_ERR, "ME tell(mainFd): %m") ;
   else
     {
-      snprintf (offsetString, sizeof(offsetString), "%ld\n",
+      (void) sprintf (offsetString, "%ld\n",
 		      (long)(offset - offsetAdjust) ) ;
-      if ( lseek (mainFd, 0, SEEK_SET) != 0 )
+      if ( lseek (mainFd, (OFFSET_T)0, SEEK_SET) != 0 )
 	syslog (LOG_ERR, "ME seek(mainFd, 0, 0): %m") ;
       else
 	{
@@ -713,21 +747,24 @@ void openDroppedArticleFile (void)
   const char *tapeDir = getTapeDirectory() ;
 
   if (dropArtFile != NULL)
-    free (dropArtFile) ;
-
-  xasprintf (&dropArtFile, "%s/innfeed-dropped.%c%06d",
-            tapeDir, droppedFileCount + 'A', (int) myPid) ;
+    FREE (dropArtFile) ;
+  
+  dropArtFile = malloc (pathMax(tapeDir) + 1) ;
+  
+  sprintf (dropArtFile,"%s/innfeed-dropped.%c%06d",
+           tapeDir, droppedFileCount + 'A', (int) myPid) ;
 
   if ((droppedFp = fopen (dropArtFile,"w")) == NULL)
     {
-      syswarn ("ME cant open %s: loosing articles", dropArtFile) ;
+      syslog (LOG_ERR,NO_DROPPED_FILE,dropArtFile) ;
 
-      free (dropArtFile) ;
+      FREE (dropArtFile) ;
       dropArtFile = NULL ;
       
       if ((droppedFp = fopen ("/dev/null","w")) == NULL)
         {
-          die ("ME error opening /dev/null") ;
+          syslog (LOG_ERR,NO_NULL_FILE) ;
+          die ("Error opening /dev/null") ;
         }
     }
 
@@ -736,13 +773,13 @@ void openDroppedArticleFile (void)
 
 void closeDroppedArticleFile (void)
 {
-  off_t pos ;
+  long pos ;
 
   if (droppedFp == NULL)
     return ;
 
   fflush (droppedFp) ;
-  pos = ftello (droppedFp) ;
+  pos = ftell (droppedFp) ;
 
   fclose (droppedFp) ;
   droppedFp = NULL ;
@@ -750,9 +787,9 @@ void closeDroppedArticleFile (void)
   if (pos == 0 && dropArtFile != NULL)
     unlink (dropArtFile) ;
   else if (pos != 0 && dropArtFile == NULL)
-    warn ("ME lost %ld articles", droppedCount) ;
+    syslog (LOG_WARNING,LOST_ARTICLE_COUNT,droppedCount) ;
   else if (pos != 0)
-    notice ("ME dropped %ld articles", droppedCount) ;
+    syslog (LOG_NOTICE,DROPPED_ARTICLE_COUNT,droppedCount) ;
      
   droppedFileCount = (droppedFileCount + 1) % 26 ;
   droppedCount = 0 ;
@@ -764,7 +801,7 @@ static void dropArticle (const char *peerName, Article article)
 
   if (!logged)
     {
-      warn ("ME dropping articles into %s", dropArtFile) ;
+      syslog (LOG_WARNING,DROPPED_LOCATION,dropArtFile) ;
       logged = true ;
     }
   
@@ -776,6 +813,5 @@ static void dropArticle (const char *peerName, Article article)
 
 static void listenerCleanup (void)
 {
-  free (dropArtFile) ;
-  dropArtFile = NULL ;
+  FREE (dropArtFile) ;
 }
