@@ -1,39 +1,75 @@
-/*  $Id: main.c 10153 2017-06-05 12:28:01Z iulius $
-**
-**  Main routines for the innfeed program.
-**
-**  Written by James Brister <brister@vix.com>
-*/
+/* -*- c -*-
+ *
+ * Author:      James Brister <brister@vix.com> -- berkeley-unix --
+ * Start Date:  Mon, 15 Jan 1996 17:31:58 +1100
+ * Project:     INN -- innfeed
+ * File:        main.c
+ * RCSId:       $Id: main.c,v 1.25.2.1 2000/06/30 15:15:36 kondou Exp $
+ *
+ * Copyright:   Copyright (c) 1996 by Internet Software Consortium
+ *
+ *              Permission to use, copy, modify, and distribute this
+ *              software for any purpose with or without fee is hereby
+ *              granted, provided that the above copyright notice and this
+ *              permission notice appear in all copies.
+ *
+ *              THE SOFTWARE IS PROVIDED "AS IS" AND INTERNET SOFTWARE
+ *              CONSORTIUM DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
+ *              SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+ *              MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL INTERNET
+ *              SOFTWARE CONSORTIUM BE LIABLE FOR ANY SPECIAL, DIRECT,
+ *              INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+ *              WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ *              WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
+ *              TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE
+ *              USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * Description: Main routines for the innfeed program.
+ * 
+ */
+
+#if ! defined (lint)
+static const char *rcsid = "$Id: main.c,v 1.25.2.1 2000/06/30 15:15:36 kondou Exp $" ;
+static void use_rcsid (const char *rid) {   /* Never called */
+  use_rcsid (rcsid) ; use_rcsid (rid) ;
+}
+#endif
 
 #include "innfeed.h"
 #include "config.h"
 #include "clibrary.h"
-#include "portable/socket.h"
 
 #include <assert.h>
 #include <ctype.h>
 #include <errno.h>
-#include <fcntl.h>
 #include <math.h>
 #include <netdb.h>
+#include <netinet/in.h>
 #include <signal.h>
+#include <sys/socket.h>
 #include <sys/stat.h>
 #include <syslog.h>
 
+#ifdef HAVE_FCNTL_H
+# include <fcntl.h>
+#endif
+
+#ifdef HAVE_RLIMIT
+# include <sys/resource.h>
+#endif
+
 #ifdef HAVE_SYS_TIME_H
 # include <sys/time.h>
+#else
+# include <time.h>
 #endif
-#include <time.h>
 
 #if defined(HAVE_UNIX_DOMAIN_SOCKETS)
-# include "portable/socket-unix.h"
+# include <sys/un.h>
 #endif
 
-#include "inn/innconf.h"
-#include "inn/messages.h"
-#include "inn/version.h"
-#include "inn/libinn.h"
-#include "inn/storage.h"
+#include "libinn.h"
+#include "storage.h"
 
 #include "article.h"
 #include "buffer.h"
@@ -43,6 +79,7 @@
 #include "host.h"
 #include "innlistener.h"
 #include "misc.h"
+#include "msgs.h"
 #include "tape.h"
 
 #define INHERIT 1
@@ -53,31 +90,20 @@ bool talkToSelf ;
 extern int debugWrites ;
 bool sigFlag = false ;
 const char *InputFile ;
-char *configFile = NULL ;
+const char *configFile = NULL ;
 bool RollInputFile = false ;
-char *pidFile = NULL ;
-bool useMMap = true ;  /* Even if !HAVE_MMAP.  Only used when innfeed is given
-                        * file names to send instead of storage API tokens,
-                        * which is a fairly rare use case. */
+const char *pidFile = NULL ;
+bool useMMap = false ;
 void (*gPrintInfo) (void) ;
 char *dflTapeDir;
-/* these are used by imapfeed */
-char *deliver_username  = NULL;
-char *deliver_authname  = NULL;
-char *deliver_password  = NULL;
-char *deliver_realm     = NULL;
-const char *deliver_rcpt_to   = "+%s";
-char *deliver_to_header = NULL;
 
 /* imports */
+extern char *versionInfo ;
 #if defined (sun)
 extern char *optarg ;           /* needed for Solaris */
 extern int optind;
 #endif
 extern bool genHtml ;
-extern bool debugShrinking;
-extern bool fastExit;
-extern unsigned int stdioFdMax;
 
 extern void openInputFile (void);
 
@@ -93,7 +119,7 @@ static void sigquit (int sig) ;
 static void sighup (int sig) ;
 static void sigterm (int sig) ;
 static void sigusr (int sig) ;
-static void usage (int) __attribute__ ((__noreturn__)) ;
+static void usage (int) ;
 static void gprintinfo (void) ;
 static void openLogFile (void) ;
 static void writePidFile (void) ;
@@ -108,7 +134,7 @@ static bool Mopt = false ;
 static bool Zopt = false ;
 static bool Dopt = false ;
 static int debugLevel = 0 ;
-static unsigned int initialSleep = 2 ;
+static u_int initialSleep = 2 ;
 static char *sopt = NULL ;
 static char *lopt = NULL ;
 static bool eopt = false ;
@@ -127,27 +153,31 @@ int main (int argc, char **argv)
   char *copt = NULL ;
   char *debugFile;
   bool checkConfig = false ;
+  struct rlimit rl;
   bool val;
 
-  timeToString (now, dateString, sizeof (dateString)) ;
 
-  message_program_name = strrchr (argv [0],'/');
-  if (message_program_name == NULL)
-    message_program_name = argv [0] ;
+  strcpy (dateString,ctime(&now)) ;
+  dateString [24] = '\0' ;
+
+  if ((program = strrchr (argv [0],'/')) == NULL)
+    program = argv [0] ;
   else
-    message_program_name++;
+    program++ ;
 
   gPrintInfo = gprintinfo ;
 
-  openlog (message_program_name,(int)(L_OPENLOG_FLAGS|LOG_PID),LOG_INN_PROG) ;
-  if (!innconf_read(NULL)) {
+  openlog (program,(int)(L_OPENLOG_FLAGS|LOG_PID),LOG_INN_PROG) ;
+  if (ReadInnConf() < 0) {
       syslog(LOG_ERR, "cant read inn.conf\n");
       exit(1);
   }
 
-  message_handlers_die (2, error_log_stderr_date, message_log_syslog_err) ;
-  message_handlers_warn (1, message_log_syslog_warning);
-  message_handlers_notice (1, message_log_syslog_notice) ;
+#if defined (HAVE_MMAP)
+  useMMap = true ;
+#else
+  useMMap = false ;
+#endif
 
 #define OPT_STRING "a:b:c:Cd:e:hl:mMo:p:S:s:vxyz"
 
@@ -252,7 +282,7 @@ int main (int argc, char **argv)
 
   if (seenV)
     {
-      printf ("%s version: %s\n", message_program_name, INN_VERSION_STRING);
+      warn ("%s version: %s\n",program, versionInfo) ;
       exit (0) ;
     }
 
@@ -292,17 +322,17 @@ int main (int argc, char **argv)
 
   if ( !checkConfig ) 
     {
-      notice("ME starting at %s (%s)", dateString, INN_VERSION_STRING);
+      syslog (LOG_NOTICE,STARTING_PROGRAM,versionInfo,dateString) ;
     }
 
-  val = true;
+  val = TRUE;
   if (!SMsetup(SM_PREOPEN, (void *)&val)) {
       syslog(LOG_ERR, "cant setup the storage subsystem\n");
       exit(1);
   }
   if (!SMinit()) {
-      d_printf(0, "Storage manager initialization failed -- it is OK after a change in storage methods\n");
-      syslog(LOG_ERR, "Storage manager initialization failed -- it is OK after a change in storage methods\n");
+      d_printf(0, "Storage manager initialization failed\n");
+      syslog(LOG_ERR, "Storage manager initialization failed\n");
       exit(1);
   }
 
@@ -311,7 +341,7 @@ int main (int argc, char **argv)
       struct stat buf ;
 
       if (fstat (0,&buf) < 0)
-        logAndExit (1,"ME oserr fstat stdin: %s", strerror (errno)) ;
+        logAndExit (1,FSTAT_FAILURE,"stdin") ;
       else if (S_ISREG (buf.st_mode))
         InputFile = "";
     }
@@ -334,8 +364,8 @@ int main (int argc, char **argv)
                   "Empty pathname for ``-c'' option") ;
       exit (1) ;
     }
-  configFile = concatpath(innconf->pathetc, copt ? copt : CONFIG_FILE);
-  dflTapeDir = concatpath(innconf->pathspool, TAPE_DIRECTORY);
+  configFile = buildFilename(innconf->pathetc, copt ? copt : CONFIG_FILE);
+  dflTapeDir = buildFilename(innconf->pathspool, TAPE_DIRECTORY);
 
   rval = readConfig (configFile,(checkConfig ? stderr : NULL),
                      checkConfig,loggingLevel > 0);
@@ -350,26 +380,20 @@ int main (int argc, char **argv)
   if (checkConfig)
     {
       if (!rval)
-        {
-          fprintf (stderr,"config loading failed.\n") ;
-          exit (1) ;
-        }
+        fprintf (stderr,"config loading failed.\n") ;
       else
-        {
-          fprintf (stderr,"config loading succeeded.\n") ;
-          exit (0) ;
-        }
+        fprintf (stderr,"config loading succeeded.\n") ;
+      exit (1) ;
     }
   else if (!rval)
     exit (1) ;
 
-  debugFile = concatpath(innconf->pathlog, DEBUG_FILE);
+  debugFile = buildFilename (innconf->pathlog, DEBUG_FILE);
   if (loggingLevel == 0 && fileExistsP (debugFile))
     loggingLevel = 1 ;
-  free(debugFile);
 
   if (logFile == NULL && ! isatty (fileno (stderr)))
-    logFile = concatpath(innconf->pathlog, LOG_FILE);
+    logFile = buildFilename (innconf->pathlog, LOG_FILE) ;
 
   if (logFile)
     openLogFile () ;
@@ -384,11 +408,15 @@ int main (int argc, char **argv)
       int pid ;
 
       if (pipe (fds) < 0)
-        sysdie ("ME fatal pipe") ;
+        {
+          syslog (LOG_CRIT,PIPE_FAILURE) ;
+          exit (1) ;
+        }
 
       if ((pid = fork ()) < 0)
         {
-          sysdie ("ME fatal fork") ;
+          syslog (LOG_CRIT,FORK_FAILURE) ;
+          exit (1) ;
         }
       else if (pid == 0)
         {                       /* child */
@@ -398,7 +426,7 @@ int main (int argc, char **argv)
           close (2) ;
           dup2 (fds[1],1) ;
           dup2 (fds[1],2) ;
-          execlp ("sh", "sh", "-c", subProgram, (char *) 0) ;
+          execlp ("sh","sh", "-c", subProgram, NULL) ;
           perror ("execlp") ;
           exit (1) ;
         }
@@ -419,7 +447,10 @@ int main (int argc, char **argv)
       int pipefds [2] ;
 
       if (pipe (pipefds) != 0)
-        sysdie ("ME fatal pipe") ;
+        {
+          syslog (LOG_ERR,PIPE_FAILURE) ;
+          exit (1) ;
+        }
 
       close (0) ;
       dup2 (pipefds [0], 0) ;
@@ -429,7 +460,10 @@ int main (int argc, char **argv)
     }
 
   if (chdir (newsspool) != 0)
-    sysdie ("ME fatal chdir %s", newsspool) ;
+    {
+      syslog (LOG_ERR,CD_FAILED,newsspool) ;
+      exit (1) ;
+    }
 
     /* hook up the endpoint to the source of new article information (usually
        innd). */
@@ -444,13 +478,33 @@ int main (int argc, char **argv)
 
   sleep (initialSleep) ;
 
-  if (innconf->rlimitnofile >= 0)
-    if (setfdlimit (innconf->rlimitnofile) < 0)
-      syswarn ("ME oserr setrlimit(RLIM_NOFILE,%ld)", innconf->rlimitnofile) ;
 
-  if (innconf->timer != 0)
-    TMRinit (TMR_MAX) ;
+#if defined(HAVE_RLIMIT) && defined(RLIMIT_NOFILE)
+  /* now lower maximum open file limit to match what select(2) can handle. */
+  if (innconf->rlimitnofile >= 0) {
+    if (getrlimit(RLIMIT_NOFILE,&rl) != 0)
+      syslog (LOG_ERR,GETRLIM_FAILED) ;
+    else
+      {
+#if defined (FD_SETSIZE)
+	u_int fd_max = FD_SETSIZE ;
+#else
+	u_int fd_max = sizeof (fd_set) * CHAR_BIT ;
+#endif
+	if (innconf->rlimitnofile < fd_max)
+	  fd_max = innconf->rlimitnofile;
 
+	if (rl.rlim_max > fd_max)
+	  {
+	    rl.rlim_max = rl.rlim_cur = fd_max ;
+	    if (setrlimit (RLIMIT_NOFILE,&rl) != 0)
+	      syslog (LOG_ERR,SETRLIM_FAILED,(long)fd_max);
+	  }
+      }
+  }
+#endif /* HAVE_RLIMIT && RLIMIT_NOFILE */
+      
+  
   configHosts (talkToSelf) ;
 
   if (InputFile && *InputFile) {
@@ -487,110 +541,118 @@ int main (int argc, char **argv)
 static void usage (int val)
 {
   fprintf (stderr,"usage: %s [ options ] [ file ]\n\n",
-           message_program_name) ;
-  fprintf (stderr,"Version: %s\n\n",INN_VERSION_STRING) ;
+           program) ;
+  fprintf (stderr,"Version: %s\n\n",versionInfo) ;
   fprintf (stderr,"Config file: %s\n",CONFIG_FILE) ;
   fprintf (stderr,"Backlog directory: %s/%s\n", innconf->pathspool, TAPE_DIRECTORY) ;
   fprintf (stderr,"\nLegal options are:\n") ;
   fprintf (stderr,"\t-a dir      Use the given directory as the top of the article spool\n") ;
 
   fprintf (stderr,"\t-b dir      Use the given directory as the the storage\n");
-  fprintf (stderr,"\t            place for backlog files and lock files\n");
+  fprintf (stderr,"\t            place for backlog files and lock files.\n");
 
   fprintf (stderr,"\t-c file     Use the given file as the config file instead of the\n");
   fprintf (stderr,"\t            default of %s\n",CONFIG_FILE);
 
-  fprintf (stderr,"\t-C          Check the config file and then exit\n") ;
-  fprintf (stderr,"\t-d num      Set the logging level to num (an integer).\n");
-  fprintf (stderr,"\t            Larger value means more logging.  0 means no\n");
-  fprintf (stderr,"\t            logging.  The default is 0\n");
+  fprintf (stderr,"\t-C          Check the config file and then exit.\n") ;
+  fprintf (stderr,"\t-d num      set the logging level to num (an integer).\n");
+  fprintf (stderr,"\t            Larger value means more logging. 0 means no\n");
+  fprintf (stderr,"\t            logging. The default is 0\n");
 
   fprintf (stderr,"\t-e bytes    Keep the output backlog files to no bigger\n");
   fprintf (stderr,"\t            than %.2f times this number\n",LIMIT_FUDGE);
 
-  fprintf (stderr,"\t-h          Print this message\n");
+  fprintf (stderr,"\t-h          print this message\n");
 
-  fprintf (stderr,"\t-l file     Redirect stderr and stdout to the given file.\n");
-  fprintf (stderr,"\t            When run under INN, they normally are redirected to\n");
-  fprintf (stderr,"\t            /dev/null.  This is needed if using '-d'\n");
+  fprintf (stderr,"\t-l file     redirect stderr and stdout to the given file.\n");
+  fprintf (stderr,"\t            When run under INN they normally are redirected to\n");
+  fprintf (stderr,"\t            /dev/null. This is needed if using '-d'.\n");
 
   fprintf (stderr,"\t-m          Log information on all missing articles\n");
 
   fprintf (stderr,"\t-M          Turn *off* use of mmap\n") ;
 #if ! defined (HAVE_MMAP)
-  fprintf (stderr,"\t            (a no-op as this excutable has been built without mmap support)\n") ;
+  fprintf (stderr,"\t            (a no-op as this excutable has been built without mmap support\n") ;
 #endif
-  fprintf (stderr,"\t-o bytes    Set a limit for the maximum number of bytes of article\n");
-  fprintf (stderr,"\t            data innfeed is supposed to keep in memory\n");
 
   fprintf (stderr,"\t-p file     Write the process id to the given file\n") ;
-  fprintf (stderr,"\t            instead of the default of %s;\n",PID_FILE);
-  fprintf (stderr,"\t            a relative path is relative to %s\n", innconf->pathrun) ;
+  fprintf (stderr,"\t            instead of the default of %s\n",PID_FILE);
+  fprintf (stderr,"\t            A relative path is relative to %s\n", innconf->pathrun) ;
 
-  fprintf (stderr,"\t-s command  Run the given command in a subprocess and use\n");
+  fprintf (stderr,"\t-s command  run the given command in a subprocess and use\n");
   fprintf (stderr,"\t            its output as article information instead of\n");
   fprintf (stderr,"\t            running under innd\n");
 
-  fprintf (stderr,"\t-S file     Use the given filename instead of innfeed.status;\n") ;
-  fprintf (stderr,"\t            relative path names start from %s\n", innconf->pathlog) ;
+  fprintf (stderr,"\t-S file     Use the give filename instead of innfeed.status\n") ;
+  fprintf (stderr,"\t            relative pathnames start from %s\n", innconf->pathlog) ;
 
-  fprintf (stderr,"\t-v          Print version information\n");
+  fprintf (stderr,"\t-v          print version information\n");
 
   fprintf (stderr,"\t-x          Do not read any article information off stdin,\n");
   fprintf (stderr,"\t            but simply process backlog files and then exit\n");
   fprintf (stderr,"\t            when done\n");
 
-  fprintf (stderr,"\t-y          Add peers dynamically.  If an unrecognized peer name\n");
+  fprintf (stderr,"\t-y          Add peers dynamically. If an unrecognized peername\n");
   fprintf (stderr,"\t            is received from innd, then it is presumed to also\n");
-  fprintf (stderr,"\t            be the IP name and a new peer binding is set up\n");
+  fprintf (stderr,"\t            be the ip name and a new peer binding is set up\n");
 
-  fprintf (stderr,"\t-z          Have each of the connections issue their own stats\n");
+  fprintf (stderr,"\t-z          have each of the connections issue their own stats\n");
   fprintf (stderr,"\t            whenever they close, or whenever their controller\n");
   fprintf (stderr,"\t            issues its own stats\n");
 
   exit (val) ;
 }
 
-static void sigterm (int sig UNUSED)
+static void sigterm (int sig)
 {
-  notice ("ME received shutdown signal") ;
+  (void) sig ;
+  
+  syslog(LOG_NOTICE, SHUTDOWN_SIGNAL);
   shutDown (mainListener) ;
 }
 
-static void sigquit (int sig UNUSED)
+static void sigquit (int sig)
 {
+  (void) sig ;
+  
   sigterm (0) ;
 }
 
-static void sigint (int sig UNUSED)
+static void sigint (int sig)
 {
+  (void) sig ;
+
   gprintinfo () ;
 }
 
-static void sighup (int sig UNUSED)
+static void sighup (int sig)
 {
-  notice ("ME reloading config file %s", configFile) ;
+  (void) sig ;
+  
+  syslog(LOG_NOTICE, CONFIG_RELOAD, configFile);
 
   if (!readConfig (configFile,NULL,false,loggingLevel > 0))
     {
-      die ("ME config aborting, error parsing config file") ;
+      syslog (LOG_ERR,PARSE_FAILURE) ;
+      exit (1) ;
     }
 
   configHosts (talkToSelf) ;
-
-  notice ("ME reloading log file %s", logFile) ;
-  openLogFile() ;
 }
 
-static void sigemt (int sig UNUSED)
+static void sigemt (int sig)
 {
+  (void) sig ;
+
   gFlushTapes () ;
 }
 
-static void sigalrm (int sig UNUSED)
+static void sigalrm (int sig)
 {
+  (void) sig ;
+  
   if (InputFile == NULL)
-    warn ("ME signal SIGALRM in non-funnel-file mode ignored") ;
+    syslog (LOG_ERR,IGNORE_SIGALRM) ;
   else 
     {
       RollInputFile = true;
@@ -598,8 +660,11 @@ static void sigalrm (int sig UNUSED)
     }
 }
 
-static void sigchld (int sig UNUSED)
+static void sigchld (int sig)
 {
+
+  (void) sig ;                  /* keep lint happy */
+
 #if 0
   wait (&status) ;              /* we don't care */
 #endif
@@ -611,11 +676,11 @@ static void sigchld (int sig UNUSED)
 static void sigusr (int sig)
 {
   if (sig == SIGUSR1) {
+    syslog(LOG_NOTICE, INCR_LOGLEVEL, loggingLevel);
     loggingLevel++ ;
-    notice ("ME increasing logging level to %d", loggingLevel) ;
   } else if (sig == SIGUSR2 && loggingLevel > 0) {
+    syslog(LOG_NOTICE, DECR_LOGLEVEL, loggingLevel);
     loggingLevel-- ;
-    notice ("ME decreasing logging level to %d", loggingLevel) ;
   }    
 }
 
@@ -680,14 +745,13 @@ static void gprintinfo (void)
 {
   char *snapshotFile;
   FILE *fp;
-  char nowString[30];
   time_t now = theTime() ;
 
-  snapshotFile = concatpath(innconf->pathlog, SNAPSHOT_FILE);
+  snapshotFile = buildFilename(innconf->pathlog, SNAPSHOT_FILE);
   fp = fopen (snapshotFile,"a") ;
   if (fp == NULL)
     {
-      syswarn ("ME fopen %s", snapshotFile) ;
+      syslog (LOG_ERR,FOPEN_FAILURE,snapshotFile) ;
       free(snapshotFile);
       return ;
     }
@@ -699,9 +763,8 @@ static void gprintinfo (void)
   setbuf (fp, NULL) ;
 #endif
 
-  timeToString (now, nowString, sizeof (nowString)) ;
-  fprintf (fp,"----------------------------System snaphot taken at: %s\n\n",
-           nowString) ;
+  fprintf (fp,"----------------------------System snaphot taken at: %s\n",
+           ctime (&now)) ;
   gPrintListenerInfo (fp,0) ;
   fprintf (fp,"\n\n\n\n") ;
   gPrintHostInfo (fp,0) ;
@@ -728,20 +791,16 @@ static int mainConfigLoadCbk (void *data)
     {
       if ( !isDirectory (p) && isDirectory (innconf->patharticles) )
         {
-          logOrPrint (LOG_WARNING,fp,
-                      "ME config: definition of news-spool (%s) is a"
-                      " non-existant directory. Using %s",p,
-                      innconf->patharticles) ;
-          p = xstrdup (innconf->patharticles) ;
+          logOrPrint (LOG_WARNING,fp,BADSPOOL_CHANGE,p,innconf->patharticles) ;
+          p = strdup (innconf->patharticles) ;
         }
       else if (!isDirectory (p))
         logAndExit (1,"Bad spool directories: %s, %s\n",p,innconf->patharticles) ;
     }
   else if (!isDirectory (innconf->patharticles))
-    logAndExit (1,"ME config: no definition of news-spool, and %s is no good",
-                innconf->patharticles);
+    logAndExit (1,SPOOL_NODEF,innconf->patharticles);
   else
-    p = xstrdup (innconf->patharticles) ;
+    p = strdup (innconf->patharticles) ;
   newsspool = p ;
 
   /***************************************************/
@@ -749,7 +808,7 @@ static int mainConfigLoadCbk (void *data)
   if (getString (topScope,"input-file",&p,NO_INHERIT))
     {
       if (*p != '\0')
-	InputFile = concatpath(getTapeDirectory(), p);
+	InputFile = buildFilename (getTapeDirectory(),p) ;
       else
 	InputFile = "" ;
       free (p) ;
@@ -757,18 +816,18 @@ static int mainConfigLoadCbk (void *data)
   
   if (getString (topScope,"pid-file",&p,NO_INHERIT))
     {
-      pidFile = concatpath(innconf->pathrun, p);
+      pidFile = buildFilename (innconf->pathrun,p) ;
       free (p) ;
     }
   else
-    pidFile = concatpath(innconf->pathrun, PID_FILE);
+    pidFile = buildFilename (innconf->pathrun,PID_FILE) ;
   
   if (getInteger (topScope,"debug-level",&ival,NO_INHERIT))
-    loggingLevel = (unsigned int) ival ;
+    loggingLevel = (u_int) ival ;
   
   
   if (getInteger (topScope,"initial-sleep",&ival,NO_INHERIT))
-    initialSleep = (unsigned int) ival ;
+    initialSleep = (u_int) ival ;
   
   
   if (getBool (topScope,"use-mmap",&bval,NO_INHERIT))
@@ -777,53 +836,9 @@ static int mainConfigLoadCbk (void *data)
   
   if (getString (topScope,"log-file",&p,NO_INHERIT))
     {
-      logFile = concatpath(innconf->pathlog, p);
-      free (p) ;
+      logFile = buildFilename (innconf->pathlog,p) ;
+      FREE (p) ;
     }
-
-  if (getString (topScope,"log-time-format",&p,NO_INHERIT))
-    {
-      free(timeToStringFormat);
-      timeToStringFormat = p;
-    }
-
-   /* For imap/lmtp delivering */
-  if (getString (topScope,"deliver-username",&p, NO_INHERIT))
-    {   
-        deliver_username = p;
-      /* don't need to free */
-    }
-
-  if (getString (topScope,"deliver-authname",&p, NO_INHERIT))
-    {
-      deliver_authname = p;
-      /* don't need to free */
-    }
-
-  if (getString (topScope,"deliver-password",&p, NO_INHERIT))
-    {
-      deliver_password = p;
-      /* don't need to free */
-    }
-
-  if (getString (topScope,"deliver-realm",&p, NO_INHERIT))
-    {
-      deliver_realm = p;
-      /* don't need to free */
-    }
-
-  if (getString (topScope,"deliver-rcpt-to",&p, NO_INHERIT))
-    {
-      deliver_rcpt_to = p;
-      /* don't need to free */
-    }
-
-  if (getString (topScope,"deliver-to-header",&p, NO_INHERIT))
-    {
-      deliver_to_header = p;
-      /* don't need to free */
-    }
-
   
 
   return 1 ;
@@ -834,41 +849,43 @@ static int mainConfigLoadCbk (void *data)
  * can adjust config file values from options. They will be validated in the
  * second callback.
  */
-static int mainOptionsProcess (void *data UNUSED)
+static int mainOptionsProcess (void *data)
 {
   value *v ;
 
+  (void) data ;
+  
   if (bopt != NULL)
     {
       if ((v = findValue (topScope,"backlog-directory",NO_INHERIT)) != NULL) 
         {
-          free (v->v.charp_val) ;
-          v->v.charp_val = xstrdup (bopt) ;
+          FREE (v->v.charp_val) ;
+          v->v.charp_val = strdup (bopt) ;
         }
       else
-        addString (topScope,"backlog-directory",xstrdup (bopt)) ;
+        addString (topScope,"backlog-directory",strdup (bopt)) ;
     }
 
   if (aopt != NULL)
     {
       if ((v = findValue (topScope,"news-spool",NO_INHERIT)) != NULL)
         {
-          free (v->v.charp_val) ;
-          v->v.charp_val = xstrdup (aopt) ;
+          FREE (v->v.charp_val) ;
+          v->v.charp_val = strdup (aopt) ;
         }
       else
-        addString (topScope,"news-spool",xstrdup (aopt)) ;
+        addString (topScope,"news-spool",strdup (aopt)) ;
     }
 
   if (sopt != NULL)
     {
       if ((v = findValue (topScope,"status-file",NO_INHERIT)) != NULL)
         {
-          free (v->v.charp_val) ;
-          v->v.charp_val = xstrdup (sopt) ;
+          FREE (v->v.charp_val) ;
+          v->v.charp_val = strdup (sopt) ;
         }
       else
-        addString (topScope,"status-file",xstrdup (sopt)) ;
+        addString (topScope,"status-file",strdup (sopt)) ;
     }
 
 
@@ -906,11 +923,11 @@ static int mainOptionsProcess (void *data UNUSED)
     {
       if ((v = findValue (topScope,"pid-file",NO_INHERIT)) != NULL)
         {
-          free (v->v.charp_val) ;
-          v->v.charp_val = xstrdup (popt) ;
+          FREE (v->v.charp_val) ;
+          v->v.charp_val = strdup (popt) ;
         }
       else
-        addString (topScope,"pid-file",xstrdup (popt)) ;
+        addString (topScope,"pid-file",strdup (popt)) ;
     }
 
   if (Zopt)
@@ -925,22 +942,22 @@ static int mainOptionsProcess (void *data UNUSED)
     {
       if ((v = findValue (topScope,"log-file",NO_INHERIT)) != NULL)
         {
-          free (v->v.charp_val) ;
-          v->v.charp_val = xstrdup (lopt) ;
+          FREE (v->v.charp_val) ;
+          v->v.charp_val = strdup (lopt) ;
         }
       else
-        addString (topScope,"log-file",xstrdup (lopt)) ;
+        addString (topScope,"log-file",strdup (lopt)) ;
     }
 
   if (InputFile != NULL)
     {
       if ((v = findValue (topScope,"input-file",NO_INHERIT)) != NULL)
         {
-          free (v->v.charp_val) ;
-          v->v.charp_val = xstrdup (InputFile) ;
+          FREE (v->v.charp_val) ;
+          v->v.charp_val = strdup (InputFile) ;
         }
       else
-        addString (topScope,"input-file",xstrdup (InputFile)) ;
+        addString (topScope,"input-file",strdup (InputFile)) ;
     }
 
   return 1 ;
@@ -950,21 +967,17 @@ static int mainOptionsProcess (void *data UNUSED)
 
 static void mainCleanup (void)
 {
-  free ((void *)configFile) ;
-  free ((void *)pidFile) ;
-  free (logFile) ;
-  free (newsspool) ;
-  configFile = NULL ;
-  pidFile = NULL ;
-  logFile = NULL ;
-  newsspool = NULL ;
+  FREE (configFile) ;
+  FREE (pidFile) ;
+  FREE (logFile) ;
+  FREE (newsspool) ;
 }
 
 
 void mainLogStatus (FILE *fp)
 {
   fprintf (fp,"%sGlobal configuration parameters:%s\n",
-           genHtml ? "<B>" : "", genHtml ? "</B>" : "") ;
+           genHtml ? "<H2>" : "", genHtml ? "</H2>" : "") ;
   fprintf (fp,"          Mode: ") ;
   if (InputFile != NULL)
     fprintf (fp,"Funnel file") ;
@@ -978,10 +991,7 @@ void mainLogStatus (FILE *fp)
   fprintf (fp,"    News spool: %s\n",newsspool) ;
   fprintf (fp,"      Pid file: %s\n",pidFile) ;
   fprintf (fp,"      Log file: %s\n",(logFile == NULL ? "(none)" : logFile));
-  fprintf (fp,"   Debug level: %-5u        Debug shrinking: %s\n",
-           loggingLevel, boolToString(debugShrinking));
-  fprintf (fp,"     Fast exit: %-5s            stdio-fdmax: %u\n",
-           boolToString(fastExit), stdioFdMax);
-  fprintf (fp,"          Mmap: %s\n", boolToString(useMMap));
+  fprintf (fp,"   Debug level: %2ld                Mmap: %s\n",
+           (long)loggingLevel,boolToString(useMMap)) ;
   fprintf (fp,"\n") ;
 }
