@@ -4,7 +4,7 @@
  * Start Date:  Wed Dec 27 17:10:18 1995
  * Project:     INN (innfeed)
  * File:        misc.c
- * RCSId:       $Id: misc.c,v 1.8.2.5 2001/06/19 22:54:28 kondou Exp $
+ * RCSId:       $Id: misc.c,v 1.8.2.7 2002/08/24 00:23:07 rra Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -29,7 +29,7 @@
  */
 
 #if ! defined (lint)
-static const char *rcsid = "$Id: misc.c,v 1.8.2.5 2001/06/19 22:54:28 kondou Exp $" ;
+static const char *rcsid = "$Id: misc.c,v 1.8.2.7 2002/08/24 00:23:07 rra Exp $" ;
 static void use_rcsid (const char *rid) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rid) ;
 }
@@ -140,6 +140,7 @@ static void dolog (int level, const char *fmt, va_list args)
   p = malloc (out + 10) ;
   vsprintf (p,fmt,args) ;
   syslog (level,"%s",p) ;
+  free (p) ;
 }
 
 void logOrPrint (int level, FILE *fp, const char *fmt, ...)
@@ -156,7 +157,7 @@ void logOrPrint (int level, FILE *fp, const char *fmt, ...)
     {
       char buffer [512] ;
 
-      vsnprintf (buffer,sizeof (buffer),fmt,ap) ;
+      vsprintf (buffer,fmt,ap) ;
       syslog (level,buffer) ;
     }
   va_end (ap) ;
