@@ -1,19 +1,45 @@
-/*  $Id: misc.h 10283 2018-05-14 12:43:05Z iulius $
-**
-**  Miscellaneous utility functions for innfeed.
-**
-**  Written by James Brister <brister@vix.com>
-*/
+/* -*- c -*-
+ *
+ * Author:      James Brister <brister@vix.com> -- berkeley-unix --
+ * Start Date:  Wed Nov 29 23:44:47 1995
+ * Project:     INN (innfeed)
+ * File:        misc.h
+ * RCSId:       $Id: misc.h,v 1.8 1999/11/20 21:22:06 rra Exp $
+ *
+ * Copyright:   Copyright (c) 1996 by Internet Software Consortium
+ *
+ *              Permission to use, copy, modify, and distribute this
+ *              software for any purpose with or without fee is hereby
+ *              granted, provided that the above copyright notice and this
+ *              permission notice appear in all copies.
+ *
+ *              THE SOFTWARE IS PROVIDED "AS IS" AND INTERNET SOFTWARE
+ *              CONSORTIUM DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
+ *              SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+ *              MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL INTERNET
+ *              SOFTWARE CONSORTIUM BE LIABLE FOR ANY SPECIAL, DIRECT,
+ *              INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+ *              WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ *              WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
+ *              TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE
+ *              USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * Description: 
+ * 
+ */
 
 #if ! defined ( misc_h__ )
 #define misc_h__
 
 #include "config.h"
-#include "portable/macros.h"
 
-#include <stdarg.h>
 #include <sys/types.h>
 
+#if defined (DO_NEED_BOOL)
+typedef enum { false = 0, true = 1 } bool ;
+#endif
+
+
 /* These typedefs are all here because C is too stupid to let me multiply
    define typedefs to the same things (as C++ will). Hence I can't redeclare
    the typedefs to get around recursive header file includes (like host.h and
@@ -40,23 +66,29 @@ typedef void (*EndpTCB) (TimeoutId tid, void *d) ; /* see endpoint.h */
 typedef void (*EndpWorkCbk) (EndPoint ep, void *data) ;
 
 
-/* debugging information */
-extern unsigned int loggingLevel ;     /* if 0 then d_printf is a no-op */
+#if defined (DO_NEED_U_INT)
+typedef unsigned long u_long ;
+typedef unsigned int u_int ;
+typedef unsigned short u_short ;
+#endif
 
-/* used by timeToString with strftime(3) */
-extern char *timeToStringFormat ;
+/* debugging information */
+extern char *program ;
+extern u_int loggingLevel ;     /* if 0 then d_printf is a no-op */
 
 /* the current count of file desccriptors */
-extern unsigned int openfds ;
+extern u_int openfds ;
+
+/* return the maximum number of fds this process can have. */
+int maxFds (void) ;
 
 /* if level <= loggingLevel then print */
-void d_printf (unsigned int level, const char *fmt, ...)
-    __attribute__((__format__ (printf, 2, 3)));
+void d_printf (u_int level, const char *fmt, ...) __attribute__ ((__format__ (printf, 2, 3)));
 
 /* for the gethostbyname() error code */
 const char *host_err_str (void) ;
 
-/* parse a response line into it's code and body. *rest will end up pointing
+/* parse a reponse line into it's code and body. *rest will end up pointing
    into the middle of p */
 bool getNntpResponse (char *p, int *code, char **rest) ;
 
@@ -70,19 +102,16 @@ char *findNonBlankString (char *ptr, char **tail) ;
 
 /* if fp is not NULL then print to it, otherwise syslog at the level. */
 void logOrPrint (int level, FILE *fp, const char *fmt, ...)
-    __attribute__((__format__(printf, 3, 4)));
+  __attribute__ ((__format__ (printf, 3, 4)));
 
-/* Error handling functions for use with warn and die. */
-void error_log_stderr_date(int len, const char *fmt, va_list args, int err)
-    __attribute__((__format__(printf, 2, 0)));
+/* print the arguments like printf to stderr then abort() */
+void die (const char *fmt, ...) __attribute__ ((__format__ (printf, 1, 2)));
 
-/* Do cleanup and then abort, for use with die. */
-void dump_core(void)
-    __attribute__ ((noreturn));
+/* print the arguments like printf to stderr. */
+void warn (const char *fmt, ...)  __attribute__ ((__format__ (printf, 1, 2)));
 
-/* Alternate die that doesn't invoke an error handler. */
 void logAndExit (int exitVal, const char *fmt, ...)
-    __attribute__((noreturn, __format__(printf, 2, 3)));
+  __attribute__ ((__format__ (printf, 2, 3)));
 
 /* return true of the file exists and is a regular file */
 bool fileExistsP (const char *filename) ;
@@ -121,12 +150,12 @@ bool isOlder (const char *file1, const char *file2) ;
 /* converts val into a printable string */
 const char *boolToString (bool val) ;
 
-/* strftime with "%a %b %d %H:%M:%S %Y" (like ctime without linefeed) */
-char* timeToString (time_t time, char* buffer, size_t size) ;
-
 /* memory leak checker helper. */
 void addPointerFreedOnExit (char *pointerToFree) ;
 
+/* splice direcotory and fname together and return free'able string */
+char *buildFilename (const char *directory, const char *fname) ;
+
 /* string the file opened by FP to the give SIZE. The NEWNAME is the name
    of the file to have after truncation. FP will be reopened for writing on
    the new file and will be positioned at the end */
