@@ -1,4 +1,4 @@
-/*  $Revision: 1.7 $
+/*  $Revision: 1.7.2.1 $
 **
 */
 #include <stdio.h>
@@ -95,8 +95,10 @@ FILE *CA_listopen(char *pathname, FILE *FromServer, FILE *ToServer, char *reques
 FILE *CAlistopen(FILE *FromServer, FILE *ToServer, char *request)
 {
     /* Gotta talk to the server -- see if we can. */
-    if (FromServer == NULL || ToServer == NULL)
+    if (FromServer == NULL || ToServer == NULL) {
+	errno = EBADF;
 	return NULL;
+    }
 
     (void)sprintf(CApathname, "%.220s/%s", innconf->pathtmp, _PATH_TEMPACTIVE);
     (void)mktemp(CApathname);
