@@ -1,30 +1,32 @@
-/*  $Id: clientlib.c 10365 2020-05-10 12:58:37Z iulius $
+/*  $Id: clientlib.c,v 1.8.2.1 2000/06/21 23:31:12 rra Exp $
 **
 **  Routines compatible with the NNTP "clientlib" routines.
 */
 #include "config.h"
 #include "clibrary.h"
 
-#include "inn/innconf.h"
-#include "inn/libinn.h"
-#include "inn/nntp.h"
+#include "libinn.h"
+#include "nntp.h"
 
 
 FILE	*ser_rd_fp = NULL;
 FILE	*ser_wr_fp = NULL;
-char	ser_line[NNTP_MAXLEN_COMMAND + 2];
+char	ser_line[NNTP_STRLEN + 2];
+void put_server(char *buff);
+int get_server(char *buff, int buffsize);
 
 
 /*
 **  Get the name of the NNTP server.  Ignore the filename; we use
 **  our own configuration stuff.  Return pointer to static data.
 */
-char *
-getserverbyfile(char *file UNUSED)
+/* ARGSUSED0 */
+char *getserverbyfile(char *file)
 {
     static char	buff[256];
 
-    strlcpy(buff, innconf->server, sizeof(buff));
+    strncpy(buff, innconf->server, sizeof(buff));
+    buff[255] = '\0';
     return buff;
 }
 
@@ -33,19 +35,16 @@ getserverbyfile(char *file UNUSED)
 **  Get a connection to the remote news server.  Return server's reply
 **  code or -1 on error.
 */
-int
-server_init(char *host, int port)
+int server_init(char *host, int port)
 {
-    char	line2[NNTP_MAXLEN_COMMAND];
+    char	line2[NNTP_STRLEN];
 
     /* This interface may be used by clients that assume C News behavior and
        won't read inn.conf themselves. */
     if (innconf == NULL)
-        if (!innconf_read(NULL))
-            return -1;
+        if (ReadInnConf() < 0) return -1;
 
-    if (NNTPconnect(host, port, &ser_rd_fp, &ser_wr_fp, ser_line,
-                    sizeof(ser_line)) < 0) {
+    if (NNTPconnect(host, port, &ser_rd_fp, &ser_wr_fp, ser_line) < 0) {
 	if (ser_line[0] == '\0')
 	    /* I/O problem. */
 	    return -1;
@@ -55,11 +54,11 @@ server_init(char *host, int port)
     }
 
     /* Send the INN command; if understood, use that reply. */
-    put_server("MODE READER");
+    put_server("mode reader");
     if (get_server(line2, (int)sizeof line2) < 0)
 	return -1;
-    if (atoi(line2) != NNTP_ERR_COMMAND)
-	strlcpy(ser_line, line2, sizeof(ser_line));
+    if (atoi(line2) != NNTP_BAD_COMMAND_VAL)
+	(void)strcpy(ser_line, line2);
 
     /* Connected; return server's reply code. */
     return atoi(ser_line);
@@ -74,38 +73,34 @@ server_init(char *host, int port)
 **  Print a message based on the the server's initial response.
 **  Return -1 if server wants us to go away.
 */
-int
-handle_server_response(int response, char *host)
+int handle_server_response(int response, char *host)
 {
     char	*p;
 
     switch (response) {
     default:
-	printf("Unknown response code %d from %s.\n", response, host);
+	(void)printf("Unknown response code %d from %s.\n", response, host);
 	return -1;
-    case NNTP_FAIL_TERMINATING:
-        if (atoi(ser_line) == response) {
-            size_t ser_line_len = strlen(ser_line);
-            if (ser_line_len > 4) {
-                p = &ser_line[ser_line_len - 1];
-                if (*p == '\n' && *--p == '\r')
-                    *p = '\0';
-                if (p > &ser_line[3]) {
-                    printf("News server %s unavailable: %s\n", host,
-                           &ser_line[4]);
-                    return -1;
-                }
-            }
-        }
-        printf("News server %s unavailable, try later.\n", host);
-        return -1;
-    case NNTP_ERR_ACCESS:
-	printf(CANTUSE, host);
+     case NNTP_GOODBYE_VAL:
+	if (atoi(ser_line) == response) {
+	    p = &ser_line[strlen(ser_line) - 1];
+	    if (*p == '\n' && *--p == '\r')
+		*p = '\0';
+	    if (p > &ser_line[3]) {
+		(void)printf("News server %s unavailable: %s\n", host,
+			&ser_line[4]);
+		return -1;
+	    }
+	}
+	(void)printf("News server %s unavailable, try later.\n", host);
 	return -1;
-    case NNTP_OK_BANNER_NOPOST:
-	printf("%s.\n", CANTPOST);
+    case NNTP_ACCESS_VAL:
+	(void)printf(CANTUSE, host);
+	return -1;
+    case NNTP_NOPOSTOK_VAL:
+	(void)printf("%s.\n", CANTPOST);
 	/* FALLTHROUGH */
-    case NNTP_OK_BANNER_POST:
+    case NNTP_POSTOK_VAL:
 	break;
     }
     return 0;
@@ -115,11 +110,10 @@ handle_server_response(int response, char *host)
 /*
 **  Send a line of text to the server.
 */
-void
-put_server(const char *buff)
+void put_server(char *buff)
 {
-    fprintf(ser_wr_fp, "%s\r\n", buff);
-    fflush(ser_wr_fp);
+    (void)fprintf(ser_wr_fp, "%s\r\n", buff);
+    (void)fflush(ser_wr_fp);
 }
 
 
@@ -127,10 +121,9 @@ put_server(const char *buff)
 **  Get a line of text from the server, strip trailing \r\n.
 **  Return -1 on error.
 */
-int
-get_server(char *buff, int buffsize)
+int get_server(char *buff, int buffsize)
 {
-    char	*p;
+    char	        *p;
 
     if (fgets(buff, buffsize, ser_rd_fp) == NULL)
 	return -1;
@@ -145,17 +138,17 @@ get_server(char *buff, int buffsize)
 **  Send QUIT and close the server.
 */
 void
-close_server(void)
+close_server()
 {
-    char	buff[NNTP_MAXLEN_COMMAND];
+    char	buff[NNTP_STRLEN];
 
     if (ser_wr_fp != NULL && ser_rd_fp != NULL) {
 	put_server("QUIT");
-	fclose(ser_wr_fp);
+	(void)fclose(ser_wr_fp);
 	ser_wr_fp = NULL;
 
-	get_server(buff, (int)sizeof buff);
-	fclose(ser_rd_fp);
+	(void)get_server(buff, (int)sizeof buff);
+	(void)fclose(ser_rd_fp);
 	ser_rd_fp = NULL;
     }
 }
