@@ -1,4 +1,4 @@
-/*  $Id: ftello.c 3681 2000-07-29 22:55:18Z rra $
+/*  $Id: ftello.c,v 1.1.2.2 2000/08/05 22:49:28 rra Exp $
 **
 **  Replacement for a missing ftello.
 **
@@ -13,6 +13,9 @@
 #include "config.h"
 #include "clibrary.h"
 
+/* Make sure we get the system ftell (clibrary.h #defines it to ftello). */
+#undef ftell
+
 #if HAVE_LARGE_FPOS_T
 
 off_t
