@@ -1,4 +1,4 @@
-/*  $Revision: 1.78.2.24 $
+/*  $Revision: 1.78.2.25 $
 **
 **  NNTP server for readers (NNRP) for InterNetNews.
 **  This server doesn't do any real load-limiting, except for what has
@@ -1211,6 +1211,10 @@ main(int argc, char *argv[])
 	(*cp->Function)(ac, av);
 	if (PushedBack)
 	    break;
+	if (PERMaccessconf)
+	    clienttimeout = PERMaccessconf->clienttimeout;
+	else
+	    clienttimeout = innconf->clienttimeout;
     }
 
     Reply("%s\r\n", NNTP_GOODBYE_ACK);
