@@ -1,4 +1,4 @@
-/*  $Id: perm.c,v 1.17.2.13 2002/01/31 03:48:17 vinocur Exp $
+/*  $Id: perm.c,v 1.17.2.15 2002/09/15 16:37:44 vinocur Exp $
 **
 **  How to figure out where a user comes from, and what that user can do once
 **  we know who sie is.
@@ -442,7 +442,7 @@ void SetDefaultAccess(ACCESSGROUP *curaccess)
     curaccess->nnrpdoverstats = innconf->nnrpdoverstats;
     curaccess->backoff_auth = innconf->backoff_auth;
     curaccess->backoff_db = NULL;
-    if (innconf->backoff_db)
+    if (innconf->backoff_db && *innconf->backoff_db != '\0')
 	curaccess->backoff_db = COPY(innconf->backoff_db);
     curaccess->backoff_k = innconf->backoff_k;
     curaccess->backoff_postfast = innconf->backoff_postfast;
@@ -1661,6 +1661,7 @@ static EXECSTUFF *ExecProg(char *arg0, char **args)
 	dup2(wrfd[0], 0);
 	execv(arg0, args);
 	/* if we got here, there was an error */
+	syslog(L_ERROR, "%s perm could not exec %s: %m", ClientHost, arg0);
 	exit(1);
     }
     close(rdfd[1]);
