@@ -1,4 +1,4 @@
-/*  $Id: buffindexed.c,v 1.40.2.6 2001/02/12 16:07:58 kondou Exp $
+/*  $Id: buffindexed.c,v 1.40.2.8 2002/01/17 01:41:32 kondou Exp $
 **
 **  Overview buffer and index method.
 */
@@ -1200,6 +1200,17 @@ STATIC BOOL ovsetcurindexblock(GROUPENTRY *ge) {
     syslog(L_ERROR, "%s: ovsetcurindexblock could not get ovbuff block for new, %d, %d", LocalLogName, ov.index, ov.blocknum);
     return FALSE;
   }
+  ovindexhead.next = ovnull;
+  ovindexhead.low = 0;
+  ovindexhead.high = 0;
+#ifdef MMAP_MISSES_WRITES
+  if (mmapwrite(ovbuff->fd, &ovindexhead, sizeof(OVINDEXHEAD), ovbuff->base + ov.blocknum * OV_BLOCKSIZE) != sizeof(OVINDEXHEAD)) {
+#else
+  if (pwrite(ovbuff->fd, &ovindexhead, sizeof(OVINDEXHEAD), ovbuff->base + ov.blocknum * OV_BLOCKSIZE) != sizeof(OVINDEXHEAD)) {
+#endif /* MMAP_MISSES_WRITES */
+    syslog(L_ERROR, "%s: could not write index record index '%d', blocknum '%d': %m", LocalLogName, ge->curindex.index, ge->curindex.blocknum);
+    return TRUE;
+  }
   if (ge->baseindex.index == NULLINDEX) {
     ge->baseindex = ov;
   } else {
@@ -1801,7 +1812,11 @@ BOOL buffindexed_expiregroup(char *group, int *lo) {
 	/* this may be duplicated, but ignore it in this case */
 	OVEXPremove(Gib[j].token, TRUE, NULL, 0);
       }
+#ifdef OV_DEBUG
+      freegroupblock(ge);
+#else
       freegroupblock();
+#endif
       ovgroupunmap();
       ge->expired = time(NULL);
       ge->count = 0;
@@ -1919,7 +1934,7 @@ void buffindexed_close(void) {
   FILE		*F = NULL;
   PID_T		pid;
   char		*path = NULL;
-  int		j;
+  int		i,j;
   struct ov_trace_array *trace;
   struct ov_name_table	*ntp;
 #endif /* OV_DEBUG */
