@@ -1,4 +1,4 @@
-/*  $Id: cnfs.c,v 1.73.2.8 2001/09/21 15:11:12 kondou Exp $
+/*  $Id: cnfs.c,v 1.73.2.9 2002/12/11 05:28:43 rra Exp $
 **
 **  Cyclic News File System.
 */
@@ -275,12 +275,10 @@ STATIC BOOL CNFSflushhead(CYCBUFF *cycbuff) {
       }
     } else {
       memcpy(cycbuff->bitfield, &rpx, sizeof(CYCBUFFEXTERN));
-#ifdef MMAP_NEEDS_MSYNC
-# ifdef HAVE_MSYNC_3_ARG
+#ifdef HAVE_MSYNC_3_ARG
       msync(cycbuff->bitfield, cycbuff->minartoffset, MS_ASYNC);
-# else
+#else
       msync(cycbuff->bitfield, cycbuff->minartoffset);
-# endif
 #endif
     }
     cycbuff->needflush = FALSE;
