@@ -1,4 +1,4 @@
-/*  $Id: ov3.c,v 1.20.2.6 2000/09/05 23:24:39 kondou Exp $
+/*  $Id: ov3.c,v 1.20.2.11 2002/03/31 22:51:01 rra Exp $
 **
 **  Indexed overview method.
 */
@@ -725,7 +725,7 @@ STATIC BOOL OV3addrec(GROUPENTRY *ge, GROUPHANDLE *gh, int artnum, TOKEN token,
     ie.expires = expires;
     ie.token = token;
     
-    if (pwrite(gh->indexfd, &ie, sizeof(ie), (artnum - base) * sizeof(ie)) != sizeof(ie)) {
+    if (xpwrite(gh->indexfd, &ie, sizeof(ie), (artnum - base) * sizeof(ie)) != sizeof(ie)) {
 	syslog(L_ERROR, "tradindexed: could not write index record for %s:%d", gh->group, artnum);
 	return FALSE;
     }
@@ -809,10 +809,15 @@ void *tradindexed_opensearch(char *group, int low, int high) {
 	base = ge->base;
     } while (ge->indexinode != oldinode);
 
-    if (high < base || low < base) { /* return NULL if searching range is out */
-      OV3closegroup(gh, FALSE);
-      return NULL;
+    /* Adjust the searching range if low < base since the active file can
+       be out of sync with the overview database and this is where the
+       initial lowmark comes from. */
+    if (high < base) {
+        OV3closegroup(gh, FALSE);
+        return NULL;
     }
+    if (low < base)
+       low = base;
 
     if (!OV3mmapgroup(gh)) {
 	OV3closegroup(gh, FALSE);
@@ -945,9 +950,7 @@ STATIC BOOL OV3packgroup(char *group, int delta) {
     char                bakidx[BIG_BUFFER], oldidx[BIG_BUFFER], newidx[BIG_BUFFER];
     struct stat         sb;
     int			fd;
-    int			numentries;
     GROUPHANDLE		*gh;
-    OFFSET_T		nbytes;
 
     if (delta <= 0) return FALSE;
 
@@ -961,7 +964,7 @@ STATIC BOOL OV3packgroup(char *group, int delta) {
     syslog(L_NOTICE, "tradindexed: repacking group %s, offset %d", group, delta);
     GROUPlock(gloc, LOCK_WRITE);
 
-    if (delta > ge->base) delta = ge->base;
+    if (delta >= ge->base) delta = ge->base - 1;
 
     strcpy(bakgroup, group);
     strcat(bakgroup, "-BAK");
@@ -991,42 +994,22 @@ STATIC BOOL OV3packgroup(char *group, int delta) {
 	return FALSE;
     }
 
-    /* stat old index file so we know its actual size. */
-    if (fstat(fd, &sb) < 0) {
-	syslog(L_ERROR, "tradindexed: could not stat %s: %m", newidx);
-	close(fd);
-	OV3closegroup(gh, FALSE);
-	GROUPlock(gloc, LOCK_UNLOCK);
-	return FALSE;
-    }
-	
-
-    /* write old index records to new file */
-    numentries = ge->high - ge->low + 1;
-    nbytes = numentries * sizeof(INDEXENTRY);
-
-    /*
-    ** check to see if the actual file length is less than nbytes (since the 
-    ** article numbers may be sparse) and if so, only read/write that amount. 
-    */
-    if (nbytes > sb.st_size) {
-	nbytes = sb.st_size;
-    }
-
-    if (pwrite(fd, &gh->indexmem[ge->low - ge->base] , nbytes,
-	       sizeof(INDEXENTRY)*(ge->low - ge->base + delta)) != nbytes) {
+    if (xpwrite(fd, gh->indexmem, gh->indexlen,
+                sizeof(INDEXENTRY) * delta) < 0) {
 	syslog(L_ERROR, "tradindexed: packgroup cant write to %s: %m", newidx);
 	close(fd);
 	OV3closegroup(gh, FALSE);
 	GROUPlock(gloc, LOCK_UNLOCK);
 	return FALSE;
-    }	
+    }
+
     if (close(fd) < 0) {
 	syslog(L_ERROR, "tradindexed: packgroup cant close %s: %m", newidx);
 	OV3closegroup(gh, FALSE);
 	GROUPlock(gloc, LOCK_UNLOCK);
 	return FALSE;
     }
+
     do {
 	if (stat(newidx, &sb) < 0) {
 	    unlink(newidx);
