@@ -1,4 +1,4 @@
-/*  $Id: tradspool.c,v 1.23.2.9 2002/02/11 17:31:45 vinocur Exp $
+/*  $Id: tradspool.c,v 1.23.2.10 2002/11/09 19:54:53 rra Exp $
 **
 **  Storage manager module for traditional spool format.
 */
@@ -920,7 +920,9 @@ tradspool_freearticle(ARTHANDLE *article) {
 	    closedir(private->curdir);
 	}
 	DISPOSE(private->curdirname);
+        DISPOSE(private);
     }
+    DISPOSE(article);
 }
 
 BOOL 
